/*
 * COPYRIGHT (C) 2017
 * TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION
 * ALL RIGHTS RESERVED
 *
 * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
 * ELECTRONIC DEVICES & STORAGE CORPORATION MAKES NO OTHER WARRANTY OF ANY
 * KIND, WHETHER EXPRESS, IMPLIED OR, STATUTORY AND DISCLAIMS ANY AND ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY, SATISFACTORY QUALITY, NON
 * INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA ELECTRONIC
 * DEVICES & STORAGE CORPORATION RESERVES THE RIGHT TO INCORPORATE
 * MODIFICATIONS TO THE SOURCE CODE IN LATER REVISIONS OF IT, AND TO MAKE
 * IMPROVEMENTS OR CHANGES IN THE DOCUMENTATION OR THE PRODUCTS OR
 * TECHNOLOGIES DESCRIBED THEREIN AT ANY TIME.
 *
 * TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION SHALL NOT BE LIABLE FOR
 * ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR
 * USE OF THE SOURCE CODE OR ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO,
 * LOST REVENUES, DATA OR PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL NATURE, PUNITIVE DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS
 * ARISING OUT OF OR IN CONNECTION WITH THIS AGREEMENT, OR BEING UNUSABLE,
 * EVEN IF ADVISED OF THE POSSIBILITY OR PROBABILITY OF SUCH DAMAGES AND
 * WHETHER A CLAIM FOR SUCH DAMAGE IS BASED UPON WARRANTY, CONTRACT, TORT,
 * NEGLIGENCE OR OTHERWISE.
 */

/** @addtogroup (null)
  * @{
  */

/** @addtogroup TC3567C
  * @{
  */

#ifndef TC3567C_H
#define TC3567C_H

#ifdef __cplusplus
extern "C" {
#endif


/* -------------------------  Interrupt Number Definition  ------------------------ */

typedef enum {
/* -------------------  Cortex-M0 Processor Exceptions Numbers  ------------------- */
  Reset_IRQn                    = -15,              /*!<   1  Reset Vector, invoked on Power up and warm reset                 */
  NonMaskableInt_IRQn           = -14,              /*!<   2  Non maskable Interrupt, cannot be stopped or preempted           */
  HardFault_IRQn                = -13,              /*!<   3  Hard Fault, all classes of Fault                                 */
  SVCall_IRQn                   =  -5,              /*!<  11  System Service Call via SVC instruction                          */
  PendSV_IRQn                   =  -2,              /*!<  14  Pendable request for system service                              */
  SysTick_IRQn                  =  -1,              /*!<  15  System Tick Timer                                                */
/* ---------------------  TC3567C Specific Interrupt Numbers  --------------------- */
} IRQn_Type;


/** @addtogroup Configuration_of_CMSIS
  * @{
  */


/* ================================================================================ */
/* ================      Processor and Core Peripheral Section     ================ */
/* ================================================================================ */

/* ----------------Configuration of the Cortex-M0 Processor and Core Peripherals---------------- */
#define __CM0_REV                 0x0000            /*!< Cortex-M0 Core Revision                                               */
#define __MPU_PRESENT                  0            /*!< MPU present or not                                                    */
#define __NVIC_PRIO_BITS               4            /*!< Number of Bits used for Priority Levels                               */
#define __Vendor_SysTickConfig         0            /*!< Set to 1 if different SysTick Config is used                          */
/** @} */ /* End of group Configuration_of_CMSIS */

#include "core_cm0.h"                               /*!< Cortex-M0 processor and core peripherals                              */
#include "system_TC3567C.h"                         /*!< TC3567C System                                                        */


/* ================================================================================ */
/* ================       Device Specific Peripheral Section       ================ */
/* ================================================================================ */


/** @addtogroup Device_Peripheral_Registers
  * @{
  */


/* -------------------  Start of section using anonymous unions  ------------------ */
#if defined(__CC_ARM)
  #pragma push
  #pragma anon_unions
#elif defined(__ICCARM__)
  #pragma language=extended
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__TMS470__)
/* anonymous unions are enabled by default */
#elif defined(__TASKING__)
  #pragma warning 586
#else
  #warning Not supported compiler type
#endif



/* ================================================================================ */
/* ================                       PWM                      ================ */
/* ================================================================================ */


/**
  * @brief Pulse Width Modulation (PWM)
  */

typedef struct {                                    /*!< PWM Structure                                                         */
  
  union {
    __IO uint32_t  PWM_PCTRL_CH0;                   /*!< PWM CH0 enable control                                                */
    
    struct {
      __IO uint32_t  ENABLE     :  1;               /*!< PWM channel enable (R/W)0: Stop (default)1: StartPlease set
                                                         cycle and duty before this is set to start.                           */
      __IO uint32_t  unit_en    :  1;               /*!< 1-s timer enable (R/W)0: Timer OFF (default)1: Timer ON Please
                                                         set this off before unit_starvalue is to be changed.When this
                                                          is off, rhythm settings has no effect.                               */
      __IO uint32_t  Pol        :  1;               /*!< PWM output polarity control (R/W)0: Polarity inversion OFF (default)1:
                                                         Polarity inversion ON                                                 */
      __IO uint32_t  IntMask    :  1;               /*!< PWM interrupt mask (R/W)0: Interrupt output enabled1: Interrupt
                                                         disabled (default)                                                    */
    } PWM_PCTRL_CH0_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_PATTERN_CH0;                 /*!< PWM CH0 output mask set                                               */
    
    struct {
      __IO uint32_t  Rhythm_Pat : 20;               /*!< PWM is output during the time this defines. 1 bit corresponds
                                                         to 50 ms.0: Output mask ON (No PWM output)1: Output mask OFF
                                                          (PWM output)This has no effect when 1-s timer is OFF.                */
    } PWM_PATTERN_CH0_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_CYCLE_CH0;                   /*!< PWM CH0 cycle set                                                     */
    
    struct {
      __IO uint32_t  cycle      : 12;               /*!< Cycle count register determines the PWM output period.0 to 4095
                                                         (0x000 to 0xFFF)                                                      */
    } PWM_CYCLE_CH0_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_DUTY_CH0;                    /*!< PWM CH0 duty set                                                      */
    
    struct {
      __IO uint32_t  Duty       : 12;               /*!< Determines the duty ratio.0 to 4095 (0x000 to 0xFFF)duty ratio
                                                         = (this value)/(cycle + 1)                                            */
    } PWM_DUTY_CH0_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_UNIT_CH0;                    /*!< PWM CH0 rhythm counter period set                                     */
    
    struct {
      __IO uint32_t  Unit_startvalue: 20;           /*!< Counter value setting to count 50 ms0x0665 for 32.768 kHz (default)0x9EB0F
                                                         for 13 MHzBefore to change this value, please make sure that
                                                          PCTRL[1] unit_en = 0, STATE[2] Timer_state = 1, Pwm_state =
                                                          1.                                                                   */
    } PWM_UNIT_CH0_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_STATE_CH0;                   /*!< PWM CH0 status                                                        */
    
    struct {
      __IO uint32_t  Int_state  :  1;               /*!< INT status0: Not interrupted1: InterruptedThis is cleared when
                                                         INTClr bit 0 is set to 1.                                             */
      __IO uint32_t  Pwm_state  :  1;               /*!< Cycle counter status0: ON1: Idle                                      */
      __IO uint32_t  Timer_state:  1;               /*!< 1-s timer status0: ON1: Idle                                          */
    } PWM_STATE_CH0_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_INTCLR_CH0;                  /*!< PWM CH0 interrupt clear                                               */
    
    struct {
      __IO uint32_t  IntClr     :  1;               /*!< PWM interrupt clear register (initial 0, W)Writeing 1 to this
                                                         register clears the interrupt status.                                 */
    } PWM_INTCLR_CH0_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED[57];
  
  union {
    __IO uint32_t  PWM_PCTRL_CH1;                   /*!< PWM CH1 enable control                                                */
    
    struct {
      __IO uint32_t  ENABLE     :  1;               /*!< PWM channel enable (R/W)0: Stop (default)1: StartPlease set
                                                         cycle and duty before this is set to start.                           */
      __IO uint32_t  unit_en    :  1;               /*!< 1-s timer enable (R/W)0: Timer OFF (default)1: Timer ON Please
                                                         set this off before unit_starvalue is to be changed.When this
                                                          is off, rhythm settings has no effect.                               */
      __IO uint32_t  Pol        :  1;               /*!< PWM output polarity control (R/W)0: Polarity inversion OFF (default)1:
                                                         Polarity inversion ON                                                 */
      __IO uint32_t  IntMask    :  1;               /*!< PWM interrupt mask (R/W)0: Interrupt output enabled1: Interrupt
                                                         disabled (default)                                                    */
    } PWM_PCTRL_CH1_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_PATTERN_CH1;                 /*!< PWM CH1 output mask set                                               */
    
    struct {
      __IO uint32_t  Rhythm_Pat : 20;               /*!< PWM is output during the time this defines. 1 bit corresponds
                                                         to 50 ms.0: Output mask ON (No PWM output)1: Output mask OFF
                                                          (PWM output)This has no effect when 1-s timer is OFF.                */
    } PWM_PATTERN_CH1_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_CYCLE_CH1;                   /*!< PWM CH1 cycle set                                                     */
    
    struct {
      __IO uint32_t  cycle      : 12;               /*!< Cycle count register determines the PWM output period.0 to 4095
                                                         (0x000 to 0xFFF)                                                      */
    } PWM_CYCLE_CH1_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_DUTY_CH1;                    /*!< PWM CH1 duty set                                                      */
    
    struct {
      __IO uint32_t  Duty       : 12;               /*!< Determines the duty ratio.0 to 4095 (0x000 to 0xFFF)duty ratio
                                                         = (this value)/(cycle + 1)                                            */
    } PWM_DUTY_CH1_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_UNIT_CH1;                    /*!< PWM CH1 rhythm counter period set                                     */
    
    struct {
      __IO uint32_t  Unit_startvalue: 20;           /*!< Counter value setting to count 50 ms0x0665 for 32.768 kHz (default)0x9EB0F
                                                         for 13 MHzBefore to change this value, please make sure that
                                                          PCTRL[1] unit_en = 0, STATE[2] Timer_state = 1, Pwm_state =
                                                          1.                                                                   */
    } PWM_UNIT_CH1_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_STATE_CH1;                   /*!< PWM CH1 status                                                        */
    
    struct {
      __IO uint32_t  Int_state  :  1;               /*!< INT status0: Not interrupted1: InterruptedThis is cleared when
                                                         INTClr bit 0 is set to 1.                                             */
      __IO uint32_t  Pwm_state  :  1;               /*!< Cycle counter status0: ON1: Idle                                      */
      __IO uint32_t  Timer_state:  1;               /*!< 1-s timer status0: ON1: Idle                                          */
    } PWM_STATE_CH1_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_INTCLR_CH1;                  /*!< PWM CH1 interrupt clear                                               */
    
    struct {
      __IO uint32_t  IntClr     :  1;               /*!< PWM interrupt clear register (initial 0, W)Writeing 1 to this
                                                         register clears the interrupt status.                                 */
    } PWM_INTCLR_CH1_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[57];
  
  union {
    __IO uint32_t  PWM_PCTRL_CH2;                   /*!< PWM CH2 enable control                                                */
    
    struct {
      __IO uint32_t  ENABLE     :  1;               /*!< PWM channel enable (R/W)0: Stop (default)1: StartPlease set
                                                         cycle and duty before this is set to start.                           */
      __IO uint32_t  unit_en    :  1;               /*!< 1-s timer enable (R/W)0: Timer OFF (default)1: Timer ON Please
                                                         set this off before unit_starvalue is to be changed.When this
                                                          is off, rhythm settings has no effect.                               */
      __IO uint32_t  Pol        :  1;               /*!< PWM output polarity control (R/W)0: Polarity inversion OFF (default)1:
                                                         Polarity inversion ON                                                 */
      __IO uint32_t  IntMask    :  1;               /*!< PWM interrupt mask (R/W)0: Interrupt output enabled1: Interrupt
                                                         disabled (default)                                                    */
    } PWM_PCTRL_CH2_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_PATTERN_CH2;                 /*!< PWM CH2 output mask set                                               */
    
    struct {
      __IO uint32_t  Rhythm_Pat : 20;               /*!< PWM is output during the time this defines. 1 bit corresponds
                                                         to 50 ms.0: Output mask ON (No PWM output)1: Output mask OFF
                                                          (PWM output)This has no effect when 1-s timer is OFF.                */
    } PWM_PATTERN_CH2_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_CYCLE_CH2;                   /*!< PWM CH2 cycle set                                                     */
    
    struct {
      __IO uint32_t  cycle      : 12;               /*!< Cycle count register determines the PWM output period.0 to 4095
                                                         (0x000 to 0xFFF)                                                      */
    } PWM_CYCLE_CH2_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_DUTY_CH2;                    /*!< PWM CH2 duty set                                                      */
    
    struct {
      __IO uint32_t  Duty       : 12;               /*!< Determines the duty ratio.0 to 4095 (0x000 to 0xFFF)duty ratio
                                                         = (this value)/(cycle + 1)                                            */
    } PWM_DUTY_CH2_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_UNIT_CH2;                    /*!< PWM CH2 rhythm counter period set                                     */
    
    struct {
      __IO uint32_t  Unit_startvalue: 20;           /*!< Counter value setting to count 50 ms0x0665 for 32.768 kHz (default)0x9EB0F
                                                         for 13 MHzBefore to change this value, please make sure that
                                                          PCTRL[1] unit_en = 0, STATE[2] Timer_state = 1, Pwm_state =
                                                          1.                                                                   */
    } PWM_UNIT_CH2_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_STATE_CH2;                   /*!< PWM CH2 status                                                        */
    
    struct {
      __IO uint32_t  Int_state  :  1;               /*!< INT status0: Not interrupted1: InterruptedThis is cleared when
                                                         INTClr bit 0 is set to 1.                                             */
      __IO uint32_t  Pwm_state  :  1;               /*!< Cycle counter status0: ON1: Idle                                      */
      __IO uint32_t  Timer_state:  1;               /*!< 1-s timer status0: ON1: Idle                                          */
    } PWM_STATE_CH2_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_INTCLR_CH2;                  /*!< PWM CH2 interrupt clear                                               */
    
    struct {
      __IO uint32_t  IntClr     :  1;               /*!< PWM interrupt clear register (initial 0, W)Writeing 1 to this
                                                         register clears the interrupt status.                                 */
    } PWM_INTCLR_CH2_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED2[57];
  
  union {
    __IO uint32_t  PWM_PCTRL_CH3;                   /*!< PWM CH3 enable control                                                */
    
    struct {
      __IO uint32_t  ENABLE     :  1;               /*!< PWM channel enable (R/W)0: Stop (default)1: StartPlease set
                                                         cycle and duty before this is set to start.                           */
      __IO uint32_t  unit_en    :  1;               /*!< 1-s timer enable (R/W)0: Timer OFF (default)1: Timer ON Please
                                                         set this off before unit_starvalue is to be changed.When this
                                                          is off, rhythm settings has no effect.                               */
      __IO uint32_t  Pol        :  1;               /*!< PWM output polarity control (R/W)0: Polarity inversion OFF (default)1:
                                                         Polarity inversion ON                                                 */
      __IO uint32_t  IntMask    :  1;               /*!< PWM interrupt mask (R/W)0: Interrupt output enabled1: Interrupt
                                                         disabled (default)                                                    */
    } PWM_PCTRL_CH3_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_PATTERN_CH3;                 /*!< PWM CH3 output mask set                                               */
    
    struct {
      __IO uint32_t  Rhythm_Pat : 20;               /*!< PWM is output during the time this defines. 1 bit corresponds
                                                         to 50 ms.0: Output mask ON (No PWM output)1: Output mask OFF
                                                          (PWM output)This has no effect when 1-s timer is OFF.                */
    } PWM_PATTERN_CH3_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_CYCLE_CH3;                   /*!< PWM CH3 cycle set                                                     */
    
    struct {
      __IO uint32_t  cycle      : 12;               /*!< Cycle count register determines the PWM output period.0 to 4095
                                                         (0x000 to 0xFFF)                                                      */
    } PWM_CYCLE_CH3_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_DUTY_CH3;                    /*!< PWM CH3 duty set                                                      */
    
    struct {
      __IO uint32_t  Duty       : 12;               /*!< Determines the duty ratio.0 to 4095 (0x000 to 0xFFF)duty ratio
                                                         = (this value)/(cycle + 1)                                            */
    } PWM_DUTY_CH3_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_UNIT_CH3;                    /*!< PWM CH3 rhythm counter period set                                     */
    
    struct {
      __IO uint32_t  Unit_startvalue: 20;           /*!< Counter value setting to count 50 ms0x0665 for 32.768 kHz (default)0x9EB0F
                                                         for 13 MHzBefore to change this value, please make sure that
                                                          PCTRL[1] unit_en = 0, STATE[2] Timer_state = 1, Pwm_state =
                                                          1.                                                                   */
    } PWM_UNIT_CH3_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_STATE_CH3;                   /*!< PWM CH3 status                                                        */
    
    struct {
      __IO uint32_t  Int_state  :  1;               /*!< INT status0: Not interrupted1: InterruptedThis is cleared when
                                                         INTClr bit 0 is set to 1.                                             */
      __IO uint32_t  Pwm_state  :  1;               /*!< Cycle counter status0: ON1: Idle                                      */
      __IO uint32_t  Timer_state:  1;               /*!< 1-s timer status0: ON1: Idle                                          */
    } PWM_STATE_CH3_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PWM_INTCLR_CH3;                  /*!< PWM CH3 interrupt clear                                               */
    
    struct {
      __IO uint32_t  IntClr     :  1;               /*!< PWM interrupt clear register (initial 0, W)Writeing 1 to this
                                                         register clears the interrupt status.                                 */
    } PWM_INTCLR_CH3_b;                             /*!< BitSize                                                               */
  };
} PWM_Type;


/* ================================================================================ */
/* ================                      GPIO                      ================ */
/* ================================================================================ */


/**
  * @brief General Purpose Input/Output (GPIO)
  */

typedef struct {                                    /*!< GPIO Structure                                                        */
  
  union {
    __I  uint32_t  GPIOMON0;                        /*!< GPIO0 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low input Not dependent on the GppOutEn or hte GppMuxCfg.             */
    } GPIOMON0_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON1;                        /*!< GPIO1 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON1_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON2;                        /*!< GPIO2 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON2_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON3;                        /*!< GPIO3 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON3_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON4;                        /*!< GPIO4 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON4_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON5;                        /*!< GPIO5 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON5_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON6;                        /*!< GPIO6 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON6_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON7;                        /*!< GPIO7 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON7_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON8;                        /*!< GPIO8 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON8_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON9;                        /*!< GPIO9 input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON9_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON10;                       /*!< GPIO10 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON10_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON11;                       /*!< GPIO11 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON11_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON12;                       /*!< GPIO12 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON12_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON13;                       /*!< GPIO13 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON13_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON14;                       /*!< GPIO14 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON14_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON15;                       /*!< GPIO15 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON15_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON16;                       /*!< GPIO16 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON16_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON17;                       /*!< GPIO17 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON17_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON18;                       /*!< GPIO18 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON18_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON19;                       /*!< GPIO19 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON19_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON20;                       /*!< GPIO20 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON20_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON21;                       /*!< GPIO21 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON21_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON22;                       /*!< GPIO22 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON22_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON23;                       /*!< GPIO23 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON23_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON24;                       /*!< GPIO24 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON24_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON25;                       /*!< GPIO25 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON25_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON26;                       /*!< GPIO26 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON26_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON27;                       /*!< GPIO27 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON27_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON28;                       /*!< GPIO28 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON28_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON29;                       /*!< GPIO29 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON29_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON30;                       /*!< GPIO30 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON30_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOMON31;                       /*!< GPIO31 input monitor                                                  */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOMON31_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOA_MON;                       /*!< GPIOA input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOA_MON_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  GPIOB_MON;                       /*!< GPIOB input monitor                                                   */
    
    struct {
      __I  uint32_t  GPIOMon    :  1;               /*!< GPIO input monitor dataMonitors the input of GPIO1: High input0:
                                                         Low inputNot dependent on the GppOutEn or hte GppMuxCfg.              */
    } GPIOB_MON_b;                                  /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED[30];
  
  union {
    __IO uint32_t  GPIO_OUT0;                       /*!< GPIO0 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT0_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT1;                       /*!< GPIO1 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT1_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT2;                       /*!< GPIO2 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT2_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT3;                       /*!< GPIO3 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT3_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT4;                       /*!< GPIO4 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT4_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT5;                       /*!< GPIO5 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT5_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT6;                       /*!< GPIO6 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT6_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT7;                       /*!< GPIO7 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT7_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT8;                       /*!< GPIO8 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT8_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT9;                       /*!< GPIO9 output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT9_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT10;                      /*!< GPIO10 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT10_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT11;                      /*!< GPIO11 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT11_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT12;                      /*!< GPIO12 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT12_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT13;                      /*!< GPIO13 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT13_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT14;                      /*!< GPIO14 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT14_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT15;                      /*!< GPIO15 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT15_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT16;                      /*!< GPIO16 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT16_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT17;                      /*!< GPIO17 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT17_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT18;                      /*!< GPIO18 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT18_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT19;                      /*!< GPIO19 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT19_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT20;                      /*!< GPIO20 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT20_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT21;                      /*!< GPIO21 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT21_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT22;                      /*!< GPIO22 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT22_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT23;                      /*!< GPIO23 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT23_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT24;                      /*!< GPIO24 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT24_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT25;                      /*!< GPIO25 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT25_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT26;                      /*!< GPIO26 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT26_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT27;                      /*!< GPIO27 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT27_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT28;                      /*!< GPIO28 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT28_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT29;                      /*!< GPIO29 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT29_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT30;                      /*!< GPIO30 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT30_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT31;                      /*!< GPIO31 output data                                                    */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT31_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT3A;                      /*!< GPIOA output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUT3A_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUTB;                       /*!< GPIOB output data                                                     */
    
    struct {
      __IO uint32_t  GPIOOut    :  1;               /*!< GPIO output data Set the output level of the GPIOX.1: High output0:
                                                         Low outputThe value is output only when GPIOOutEnX = 1 and GPIOMuxCfgX
                                                          = 0.                                                                 */
    } GPIO_OUTB_b;                                  /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[30];
  
  union {
    __IO uint32_t  GPIO_OUT_EN0;                    /*!< GPIO0 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN0_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN1;                    /*!< GPIO1 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN1_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN2;                    /*!< GPIO2 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN2_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN3;                    /*!< GPIO3 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN3_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN4;                    /*!< GPIO4 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN4_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN5;                    /*!< GPIO5 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN5_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN6;                    /*!< GPIO6 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN6_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN7;                    /*!< GPIO7 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN7_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN8;                    /*!< GPIO8 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN8_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN9;                    /*!< GPIO9 output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN9_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN10;                   /*!< GPIO10 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN10_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN11;                   /*!< GPIO11 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN11_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN12;                   /*!< GPIO12 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN12_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN13;                   /*!< GPIO13 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN13_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN14;                   /*!< GPIO14 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN14_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN15;                   /*!< GPIO15 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN15_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN16;                   /*!< GPIO16 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN16_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN17;                   /*!< GPIO17 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN17_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN18;                   /*!< GPIO18 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN18_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN19;                   /*!< GPIO19 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN19_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN20;                   /*!< GPIO20 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN20_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN21;                   /*!< GPIO21 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN21_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN22;                   /*!< GPIO22 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN22_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN23;                   /*!< GPIO23 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN23_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN24;                   /*!< GPIO24 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN24_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN25;                   /*!< GPIO25 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN25_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN26;                   /*!< GPIO26 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN26_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN27;                   /*!< GPIO27 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN27_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN28;                   /*!< GPIO28 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN28_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN29;                   /*!< GPIO29 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN29_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN30;                   /*!< GPIO30 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN30_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN31;                   /*!< GPIO31 output enable                                                  */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIO_OUT_EN31_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOA_OUT_EN;                    /*!< GPIOA output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIOA_OUT_EN_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOB_OUT_EN0;                   /*!< GPIOB output enable                                                   */
    
    struct {
      __IO uint32_t  GPIOOutEn  :  1;               /*!< GPIO output enable. Enables GPIO output.1: output enable0: output
                                                         disable                                                               */
    } GPIOB_OUT_EN0_b;                              /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED2[30];
  
  union {
    __IO uint32_t  GPIO_CFG0;                       /*!< GPIO0 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG0_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG1;                       /*!< GPIO1 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG1_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG2;                       /*!< GPIO2 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG2_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG3;                       /*!< GPIO3 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG3_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG4;                       /*!< GPIO4 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG4_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG5;                       /*!< GPIO5 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG5_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG6;                       /*!< GPIO6 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG6_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG7;                       /*!< GPIO7 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG7_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG8;                       /*!< GPIO8 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG8_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG9;                       /*!< GPIO9 config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG9_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG10;                      /*!< GPIO10 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG10_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG11;                      /*!< GPIO11 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG11_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG12;                      /*!< GPIO12 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG12_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG13;                      /*!< GPIO13 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG13_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG14;                      /*!< GPIO14 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG14_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG15;                      /*!< GPIO15 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG15_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG16;                      /*!< GPIO16 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG16_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG17;                      /*!< GPIO17 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG17_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG18;                      /*!< GPIO18 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG18_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG19;                      /*!< GPIO19 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG19_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG20;                      /*!< GPIO20 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG20_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG21;                      /*!< GPIO21 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG21_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG22;                      /*!< GPIO22 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG22_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG23;                      /*!< GPIO23 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG23_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG24;                      /*!< GPIO24 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG24_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG25;                      /*!< GPIO25 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG25_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG26;                      /*!< GPIO26 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG26_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG27;                      /*!< GPIO27 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG27_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG28;                      /*!< GPIO28 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG28_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG29;                      /*!< GPIO29 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG29_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG30;                      /*!< GPIO30 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG30_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_CFG31;                      /*!< GPIO31 config                                                         */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIO_CFG31_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOA_CFG;                       /*!< GPIOA config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIOA_CFG_b;                                  /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOB_CFG;                       /*!< GPIOB config                                                          */
    
    struct {
      __IO uint32_t  GPIOIntCfg :  3;               /*!< GPIO interrupt configuration (initial 00, R/W)Sets the polarity
                                                         to use the GPIO as an external interrupt.000: prohibit the interrupt.001:
                                                          detect rising edge010: detect falling edge011: detect both edges100:
                                                          detect high level101: detect low level                               */
      __IO uint32_t  GppPullUpOff:  1;              /*!< GIO pull-down resister offTurn on/off the internal pull down
                                                         resiter.1: Internal pull-down off0: Internal pull-down onGPIO0/3/4/9/10/14
                                                         /15/20/21 are set as pull-up off.Others are set as pull-up on.When
                                                          both GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIOPullUpOff:  1;             /*!< GIO pull-up resister offTurn on/off the internal pull up resiter.1:
                                                         Internal pull-up off0: Internal pull-up onGPIO0/3/4/9/10/14/15/20/21
                                                          are set as pull-up off.Others are set as pull-up on.When both
                                                          GPIOPullDownOff = 0 and GPIOPullUpOff = 0 are to be set,the
                                                          chip forces GPIOPullDownOff = 1 and GPIOPullUpOff = 0.Valid
                                                          when the GPIO is set as input regardless of the GppMuxCfg.           */
      __IO uint32_t  GPIODrvCtrl:  2;               /*!< GPIO0 drive control.To set GPIO drive settings.00: 1 mA01: 1.5
                                                         mA (default)10: 2 mA11: 4 mAValid when the GPIO is set as output
                                                          regardless of GPIOMuxCfg.                                            */
    } GPIOB_CFG_b;                                  /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED3[30];
  
  union {
    __IO uint32_t  GPIO_MUXCFG_L;                   /*!< GPIO multiplexer config L                                             */
    
    struct {
      __IO uint32_t  GPIO0MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO1MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO2MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO3MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO4MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO5MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO6MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO7MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO8MuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPI9OMuxL  :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO10MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO11MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO12MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO13MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO14MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPI15OMuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO16MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO17MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO18MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO19MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO20MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO21MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO22MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO23MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO24MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO25MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO26MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO27MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO28MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO29MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO30MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO31MuxL :  1;               /*!< Bit 0 of GPIO multiplexer configuration.                              */
    } GPIO_MUXCFG_L_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_MUXCFG_M;                   /*!< GPIO multiplexer config M                                             */
    
    struct {
      __IO uint32_t  GPIO0MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO1MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO2MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO3MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO4MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO5MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO6MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO7MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO8MuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPI9OMuxM  :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO10MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO11MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO12MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO13MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO14MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPI15OMuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO16MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO17MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO18MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO19MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO20MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO21MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO22MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO23MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO24MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO25MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO26MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO27MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO28MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO29MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO30MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO31MuxM :  1;               /*!< Bit 1 of GPIO multiplexer configuration.                              */
    } GPIO_MUXCFG_M_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_MUXCFG_H;                   /*!< GPIO multiplexer config H                                             */
    
    struct {
      __IO uint32_t  GPIO0MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO1MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO2MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO3MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO4MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO5MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO6MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO7MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO8MuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPI9OMuxH  :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO10MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO11MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO12MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO13MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO14MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPI15OMuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO16MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO17MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO18MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO19MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO20MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO21MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO22MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO23MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO24MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO25MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO26MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO27MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO28MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO29MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO30MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
      __IO uint32_t  GPIO31MuxH :  1;               /*!< Bit 2 of GPIO multiplexer configuration.                              */
    } GPIO_MUXCFG_H_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOAB_MUXCFG;                   /*!< GPIOAB multiplexer config                                             */
    
    struct {
      __IO uint32_t  GPIOABMuxCfg:  1;              /*!< 1: SWD, 0: GPIO                                                       */
    } GPIOAB_MUXCFG_b;                              /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED4[28];
  
  union {
    __I  uint32_t  GPIO_INT;                        /*!< GPIO interrupt read                                                   */
    
    struct {
      __I  uint32_t  GPIOINT0   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT1   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT2   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT3   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT4   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT5   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT6   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT7   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT8   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT9   :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT10  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT11  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT12  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT13  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT14  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT15  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT16  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT17  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT18  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT19  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT20  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT21  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT22  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT23  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT24  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT25  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT26  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT27  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT28  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT29  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIOINT30  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
      __I  uint32_t  GPIO31INT  :  1;               /*!< Read interrupt on the GPIO.1: Interrupted0: Not interrupted           */
    } GPIO_INT_b;                                   /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOAB_INT;                      /*!< GPIO interrupt read                                                   */
    
    struct {
      __IO uint32_t  GPIOAINT   :  1;               /*!< Read interrupt on GPIOA.1: Interrupted0: Not interrupted              */
      __IO uint32_t  GPIOBINT   :  1;               /*!< Read interrupt on GPIOB.1: Interrupted0: Not interrupted              */
    } GPIOAB_INT_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_EDGECAPCLR;                 /*!< GPIO edge interrupt capture clear                                     */
    
    struct {
      __IO uint32_t  GPIO0EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO1EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO2EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO3EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO4EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO5EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO6EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO7EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO8EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO9EdgeCapClr:  1;           /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO10EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO11EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO12EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO13EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO14EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO15EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO16EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO17EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO18EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO19EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO20EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO21EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO22EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO23EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO24EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO25EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO26EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO27EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO28EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO29EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO30EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
      __IO uint32_t  GPIO31EdgeCapClr:  1;          /*!< Clear edge interrput capture on the GPIO.1: Clear0: Not clear         */
    } GPIO_EDGECAPCLR_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIOAB_EDGECAPCLR;               /*!< GPIO edge interrupt capture clear                                     */
    
    struct {
      __IO uint32_t  GPIOAEdgeCapClr:  1;           /*!< Clear edge interrput capture on GPIOA.1: Clear0: Not clear            */
      __IO uint32_t  GPIOBEdgeCapClr:  1;           /*!< Clear edge interrput capture on GPIOB.1: Clear0: Not clear            */
    } GPIOAB_EDGECAPCLR_b;                          /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OBSMUXCFG;                  /*!< GPIO Observation function selection register                          */
    
    struct {
      __IO uint32_t  ObsMuxCfg  :  1;               /*!< Always set 3.                                                         */
      __IO uint32_t  Reserved0  : 31;               /*!< Always set 0.                                                         */
    } GPIO_OBSMUXCFG_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED5[11];
  
  union {
    __I  uint32_t  GPIO_MON_WRAP;                   /*!< GPIO Input Monitor Wrap Register                                      */
    
    struct {
      __I  uint32_t  GPIO0Mon   :  1;               /*!< GPIO0 input monitor dataMonitors the input of GPIO01: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO1Mon   :  1;               /*!< GPIO1 input monitor dataMonitors the input of GPIO11: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO2Mon   :  1;               /*!< GPIO2 input monitor dataMonitors the input of GPIO21: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO3Mon   :  1;               /*!< GPIO3 input monitor dataMonitors the input of GPIO31: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO4Mon   :  1;               /*!< GPIO4 input monitor dataMonitors the input of GPIO41: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO5Mon   :  1;               /*!< GPIO5 input monitor dataMonitors the input of GPIO51: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO6Mon   :  1;               /*!< GPIO6 input monitor dataMonitors the input of GPIO61: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO7Mon   :  1;               /*!< GPIO7 input monitor dataMonitors the input of GPIO71: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO8Mon   :  1;               /*!< GPIO8 input monitor dataMonitors the input of GPIO81: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO9Mon   :  1;               /*!< GPIO9 input monitor dataMonitors the input of GPIO91: High input0:
                                                         Low input                                                             */
      __I  uint32_t  GPIO10Mon  :  1;               /*!< GPIO10 input monitor dataMonitors the input of GPIO101: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO11Mon  :  1;               /*!< GPIO11 input monitor dataMonitors the input of GPIO111: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO12Mon  :  1;               /*!< GPIO12 input monitor dataMonitors the input of GPIO121: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO13Mon  :  1;               /*!< GPIO13 input monitor dataMonitors the input of GPIO131: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO14Mon  :  1;               /*!< GPIO14 input monitor dataMonitors the input of GPIO141: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO15Mon  :  1;               /*!< GPIO15 input monitor dataMonitors the input of GPIO151: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO16Mon  :  1;               /*!< GPIO16 input monitor dataMonitors the input of GPIO161: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO17Mon  :  1;               /*!< GPIO17 input monitor dataMonitors the input of GPIO171: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO18Mon  :  1;               /*!< GPIO18 input monitor dataMonitors the input of GPIO181: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO19Mon  :  1;               /*!< GPIO19 input monitor dataMonitors the input of GPIO191: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO20Mon  :  1;               /*!< GPIO20 input monitor dataMonitors the input of GPIO201: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO21Mon  :  1;               /*!< GPIO21 input monitor dataMonitors the input of GPIO211: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO22Mon  :  1;               /*!< GPIO22 input monitor dataMonitors the input of GPIO221: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO23Mon  :  1;               /*!< GPIO23 input monitor dataMonitors the input of GPIO231: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO24Mon  :  1;               /*!< GPIO24 input monitor dataMonitors the input of GPIO241: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO25Mon  :  1;               /*!< GPIO25 input monitor dataMonitors the input of GPIO251: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO26Mon  :  1;               /*!< GPIO26 input monitor dataMonitors the input of GPIO261: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO27Mon  :  1;               /*!< GPIO27 input monitor dataMonitors the input of GPIO271: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO28Mon  :  1;               /*!< GPIO28 input monitor dataMonitors the input of GPIO281: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO29Mon  :  1;               /*!< GPIO29 input monitor dataMonitors the input of GPIO291: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO30Mon  :  1;               /*!< GPIO30 input monitor dataMonitors the input of GPIO301: High
                                                         input0: Low input                                                     */
      __I  uint32_t  GPIO31Mon  :  1;               /*!< GPIO31 input monitor dataMonitors the input of GPIO311: High
                                                         input0: Low input                                                     */
    } GPIO_MON_WRAP_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_WRAP;                   /*!< GPIO Output data Wrap Register                                        */
    
    struct {
      __IO uint32_t  GPIO0Out   :  1;               /*!< GPIO0 output dataSet the output level of GPIO01: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO1Out   :  1;               /*!< GPIO1 output dataSet the output level of GPIO11: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO2Out   :  1;               /*!< GPIO2 output dataSet the output level of GPIO21: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO3Out   :  1;               /*!< GPIO3 output dataSet the output level of GPIO31: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO4Out   :  1;               /*!< GPIO4 output dataSet the output level of GPIO41: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO5Out   :  1;               /*!< GPIO5 output dataSet the output level of GPIO51: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO6Out   :  1;               /*!< GPIO6 output dataSet the output level of GPIO61: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO7Out   :  1;               /*!< GPIO7 output dataSet the output level of GPIO71: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO8Out   :  1;               /*!< GPIO8 output dataSet the output level of GPIO81: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO9Out   :  1;               /*!< GPIO9 output dataSet the output level of GPIO91: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO10Out  :  1;               /*!< GPIO10 output dataSet the output level of GPIO101: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO11Out  :  1;               /*!< GPIO11 output dataSet the output level of GPIO111: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO12Out  :  1;               /*!< GPIO12 output dataSet the output level of GPIO121: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO13Out  :  1;               /*!< GPIO13 output dataSet the output level of GPIO131: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO14Out  :  1;               /*!< GPIO14 output dataSet the output level of GPIO141: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO15Out  :  1;               /*!< GPIO15 output dataSet the output level of GPIO151: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO16Out  :  1;               /*!< GPIO16 output dataSet the output level of GPIO161: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO17Out  :  1;               /*!< GPIO17 output dataSet the output level of GPIO171: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO18Out  :  1;               /*!< GPIO18 output dataSet the output level of GPIO181: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO19Out  :  1;               /*!< GPIO19 output dataSet the output level of GPIO191: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO20Out  :  1;               /*!< GPIO20 output dataSet the output level of GPIO201: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO21Out  :  1;               /*!< GPIO21 output dataSet the output level of GPIO211: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO22Out  :  1;               /*!< GPIO22 output dataSet the output level of GPIO221: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO23Out  :  1;               /*!< GPIO23 output dataSet the output level of GPIO231: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO24Out  :  1;               /*!< GPIO24 output dataSet the output level of GPIO241: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO25Out  :  1;               /*!< GPIO25 output dataSet the output level of GPIO251: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO26Out  :  1;               /*!< GPIO26 output dataSet the output level of GPIO261: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO27Out  :  1;               /*!< GPIO27 output dataSet the output level of GPIO271: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO28Out  :  1;               /*!< GPIO28 output dataSet the output level of GPIO281: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO29Out  :  1;               /*!< GPIO29 output dataSet the output level of GPIO291: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO30Out  :  1;               /*!< GPIO30 output dataSet the output level of GPIO301: High output0:
                                                         Low output                                                            */
      __IO uint32_t  GPIO31Out  :  1;               /*!< GPIO31 output dataSet the output level of GPIO311: High output0:
                                                         Low output                                                            */
    } GPIO_OUT_WRAP_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  GPIO_OUT_EN_WRAP;                /*!< GPIO Output Enable Wrap Register                                      */
    
    struct {
      __IO uint32_t  GPIOOutEn0 :  1;               /*!< GPIO0 output enableEnables GPIO0 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn1 :  1;               /*!< GPIO1 output enableEnables GPIO1 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn2 :  1;               /*!< GPIO2 output enableEnables GPIO2 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn3 :  1;               /*!< GPIO3 output enableEnables GPIO3 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn4 :  1;               /*!< GPIO4 output enableEnables GPIO4 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn5 :  1;               /*!< GPIO5 output enableEnables GPIO5 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn6 :  1;               /*!< GPIO6 output enableEnables GPIO6 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn7 :  1;               /*!< GPIO7 output enableEnables GPIO7 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn8 :  1;               /*!< GPIO8 output enableEnables GPIO8 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn9 :  1;               /*!< GPIO9 output enableEnables GPIO9 output1: Output enable0: Output
                                                         disable                                                               */
      __IO uint32_t  GPIOOutEn10:  1;               /*!< GPIO10 output enableEnables GPIO10 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn11:  1;               /*!< GPIO11 output enableEnables GPIO11 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn12:  1;               /*!< GPIO12 output enableEnables GPIO12 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn13:  1;               /*!< GPIO13 output enableEnables GPIO13 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn14:  1;               /*!< GPIO14 output enableEnables GPIO14 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn15:  1;               /*!< GPIO15 output enableEnables GPIO15 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn16:  1;               /*!< GPIO16 output enableEnables GPIO16 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn17:  1;               /*!< GPIO17 output enableEnables GPIO17 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn18:  1;               /*!< GPIO18 output enableEnables GPIO18 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn19:  1;               /*!< GPIO19 output enableEnables GPIO19 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn20:  1;               /*!< GPIO20 output enableEnables GPIO20 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn21:  1;               /*!< GPIO21 output enableEnables GPIO21 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn22:  1;               /*!< GPIO22 output enableEnables GPIO22 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn23:  1;               /*!< GPIO23 output enableEnables GPIO23 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn24:  1;               /*!< GPIO24 output enableEnables GPIO24 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn25:  1;               /*!< GPIO25 output enableEnables GPIO25 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn26:  1;               /*!< GPIO26 output enableEnables GPIO26 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn27:  1;               /*!< GPIO27 output enableEnables GPIO27 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn28:  1;               /*!< GPIO28 output enableEnables GPIO28 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn29:  1;               /*!< GPIO29 output enableEnables GPIO29 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn30:  1;               /*!< GPIO30 output enableEnables GPIO30 output1: Output enable0:
                                                         Output disable                                                        */
      __IO uint32_t  GPIOOutEn31:  1;               /*!< GPIO31 output enableEnables GPIO31 output1: Output enable0:
                                                         Output disable                                                        */
    } GPIO_OUT_EN_WRAP_b;                           /*!< BitSize                                                               */
  };
} GPIO_Type;


/* ================================================================================ */
/* ================                       SPI                      ================ */
/* ================================================================================ */


/**
  * @brief Serial Peripheral Interface(Master/Slave) (SPI)
  */

typedef struct {                                    /*!< SPI Structure                                                         */
  
  union {
    __IO uint32_t  SPI_CONTROL;                     /*!< SPI control                                                           */
    
    struct {
           uint32_t             :  1;
      __IO uint32_t  SETACT     :  1;               /*!< Set operation mode (R/W)0: Configuration mode1: Active mode
                                                         (default)                                                             */
           uint32_t             :  3;
      __IO uint32_t  SPSCKPH    :  1;               /*!< Specify serial clock phase (R/W)0: Sampling at the first edge
                                                         (default)1: Sampling at the second edge                               */
      __IO uint32_t  SPSCKPL    :  1;               /*!< Specify serial clock polarity (R/W)0: Sampling at high (default)1:
                                                         Sampling at low                                                       */
      __IO uint32_t  SPDIR      :  1;               /*!< Specify LSB/MSB first (R/W)0: MSB first (default)1: LSB first         */
      __IO uint32_t  SPCSEN0    :  1;               /*!< Enable CS (R/W)0: Disable1: Enable (default)                          */
           uint32_t             :  3;
      __IO uint32_t  SPCSPL0    :  1;               /*!< Set CS polarity (R/W)0: Low active (default)1: High active            */
           uint32_t             : 18;
      __IO uint32_t  SLAVE      :  1;               /*!< Set master/slave mode (R/W)0: Master mode (default)1: Slave
                                                         mode                                                                  */
    } SPI_CONTROL_b;                                /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  SPI_TIMINGCONTROL;               /*!< SPI timing control                                                    */
    
    struct {
           uint32_t             :  8;
      __IO uint32_t  BASE       :  8;               /*!< Set frequency devisor (R/W)0: Not allowed1-255: Allowed f_SPI
                                                         = 13/(devisor x 2) MHze.g. when devisor = 1, f_SPI = 6.5 MHz.         */
    } SPI_TIMINGCONTROL_b;                          /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  SPI_TXDATA;                      /*!< SPI TX data                                                           */
    
    struct {
      __IO uint32_t  TX         : 16;               /*!< Set TX data (R/W) Default value is zero.                              */
      __IO uint32_t  BYTE       :  2;               /*!< Set transfer byte length (R/W)00: 1 byte (default)01: 2 bytes10:
                                                         3 bytes (valid for read)11: 4 bytes (valid for read)                  */
      __IO uint32_t  CMD        :  1;               /*!< Set transfer command (R/W)0: Write (default)1: Read                   */
      __IO uint32_t  CONT       :  1;               /*!< Set continuous transfer (R/W)0: Deassert CS per word (default)1:
                                                         Keep CS between words                                                 */
      __IO uint32_t  WRBIT      :  4;               /*!< Set valid TX bit length (R/W)0x0: The setting at bit[17:16]
                                                         is applied (default).0x1: 1 bit0x2: 2 bit...0xF: 15 bit               */
      __IO uint32_t  LEN        :  8;               /*!< Default value is zero.When CMD is write (bit[18] = 0), set TX
                                                         options (R/W). bit[31:26] Reserved bit[25] SPI DO polarity (0:
                                                          L, 1: H) bit[24] SPI DO output status (0: keep the last data,
                                                          1: output H/L set at bit 25)When CMD is read (bit[18] = 1),
                                                          set RX data length (R/W). bit[31:24] RX data length (unit is
                                                          defined at bit[17:16])                                               */
    } SPI_TXDATA_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  SPI_RXDATA;                      /*!< SPI RX Data                                                           */
    
    struct {
      __I  uint32_t  RX         : 32;               /*!< Get RX data (R)When data is 24 bit length, [31:24] = 0x00 (default).When
                                                         data is 16 bit length, [31:16] = 0x0000.When data is 8 bit length,
                                                          [31:8] = 0x000000.                                                   */
    } SPI_RXDATA_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  SPI_INTCONTROL;                  /*!< SPI intrrupt control                                                  */
    
    struct {
           uint32_t             : 12;
      __IO uint32_t  TXCLR      :  1;               /*!< Clear TX FIFO (R/W)0: Do not clear (default)1: Clear After claer,
                                                         this register becomes 0.                                              */
           uint32_t             :  7;
      __IO uint32_t  RXCLR      :  1;               /*!< Clear RX FIFO (R/W)0: Do not clear (default)1: Clear After claer,
                                                         this register becomes 0.                                              */
    } SPI_INTCONTROL_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  SPI_INTSTATUS;                   /*!< SPI interrupt status                                                  */
    
    struct {
           uint32_t             :  8;
      __I  uint32_t  TXFUL      :  1;               /*!< Read the status of TX FIFO (R)0: TX FIFO is full.1: TX FIFO
                                                         is not full.                                                          */
      __I  uint32_t  RXEMP      :  1;               /*!< Read the status of RX FIFO (R)0: RX FIFO is empty.1: RX FIFO
                                                         is not empty.                                                         */
           uint32_t             :  1;
      __I  uint32_t  SIFACT     :  1;               /*!< Read the status of serial interface (R)0: Idle (default)1: Operating  */
           uint32_t             : 12;
      __I  uint32_t  TXNUM      :  4;               /*!< Read deta length in TX FIFO (R)0000: 0 (default)0001: 1...0111:
                                                         71000: 8Others: Don't care                                            */
      __I  uint32_t  RXNUM      :  4;               /*!< Read deta length in RX FIFO (R)0000: 0 (default)0001: 1...0111:
                                                         71000: 8Others: Don't care                                            */
    } SPI_INTSTATUS_b;                              /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED[2];
  
  union {
    __IO uint32_t  SPI_TIMINGCONTROL2;              /*!< SPI timing control                                                    */
    
    struct {
           uint32_t             : 16;
      __IO uint32_t  ADDSPLDLY  :  2;               /*!< Add sampling delay of RX data (R/W) 01: 1 clk delay (fixed)           */
    } SPI_TIMINGCONTROL2_b;                         /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[2];
  
  union {
    __IO uint32_t  SPI_TXRXLENGTH;                  /*!< SPI Data Langth                                                       */
    
    struct {
      __IO uint32_t  TxLEN      :  5;               /*!< Set the length of Tx data length00-02: Forbidden03: 4bit04:
                                                         5bit...1E: 31bit1F: 32bit                                             */
      __IO uint32_t  Reserved1  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  RxLEN      :  5;               /*!< Set the length of Rx data length00-02: Forbidden.03: 4bit04:
                                                         5bit...1E:31bit1F:32bit                                               */
      __IO uint32_t  Reserved0  : 19;               /*!< Do not change the values.                                             */
    } SPI_TXRXLENGTH_b;                             /*!< BitSize                                                               */
  };
} SPI_Type;


/* ================================================================================ */
/* ================                      Clock                     ================ */
/* ================================================================================ */


/**
  * @brief Clock Supply for SPI and PWM (Clock)
  */

typedef struct {                                    /*!< Clock Structure                                                       */
  __I  uint32_t  RESERVED;
  
  union {
    __IO uint32_t  CG_PWM_CTRL;                     /*!< PWM clock mode set                                                    */
    
    struct {
      __IO uint32_t  PWM0ClkSel :  1;               /*!< Select PWM0 clock1: MAX 13 MHz (This division ratio can be changed
                                                         in CG_DIVNUM4)0: 32 kHzPlease set disable to PWM0SlpClkEn and
                                                          PWM0ClkEn before changing this register.                             */
      __IO uint32_t  PWM1ClkSel :  1;               /*!< Select PWM1 clock1: MAX 13 MHz (This division ratio can be changed
                                                         in CG_DIVNUM4)0: 32 kHzPlease set disable to PWM1SlpClkEn and
                                                          PWM1ClkEn before changing this register.                             */
      __IO uint32_t  PWM2ClkSel :  1;               /*!< Select PWM2 clock1: MAX 13 MHz (This division ratio can be changed
                                                         in CG_DIVNUM4)0: 32 kHzPlease set disable to PWM2SlpClkEn and
                                                          PWM2ClkEn before changing this register.                             */
      __IO uint32_t  PWM3ClkSel :  1;               /*!< Select PWM3 clock1: MAX 13 MHz (This division ratio can be changed
                                                         in CG_DIVNUM4)0: 32 kHzPlease set disable to PWM3SlpClkEn and
                                                          PWM3ClkEn before changing this register.                             */
      __IO uint32_t  Reserved0  : 28;               /*!< Do not change the values.                                             */
    } CG_PWM_CTRL_b;                                /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[2];
  
  union {
    __IO uint32_t  CG_DIVNUM3;                      /*!< Division ration for PWM1 and PWM0 config                              */
    
    struct {
      __IO uint32_t  PWM0_DIVNUM: 12;               /*!< Division ratio of 26MHz clock to generate PWM0 clock.PWM0 clock
                                                         ON/OFF can be set on CG_CLK_CTRL2 register.This value can be
                                                          changed regardless of the clock ON/OFF.However, the output clock
                                                          may be unstable right after the change of this register.division
                                                          ratio = (this value + 1) * 2default value is 0x000 (Divided
                                                          by 2)                                                                */
      __IO uint32_t  Reserved1  :  4;               /*!< Do not change the values.                                             */
      __IO uint32_t  PWM1_DIVNUM: 12;               /*!< Division ratio of 26MHz clock to generate PWM1 clock.PWM1 clock
                                                         ON/OFF can be set on CG_CLK_CTRL2 register.This value can be
                                                          changed regardless of the clock ON/OFF.However, the output clock
                                                          may be unstable right after the change of this register.division
                                                          ratio = (this value + 1) * 2default value is 0x000 (Divided
                                                          by 2)                                                                */
      __IO uint32_t  Reserved0  :  4;               /*!< Do not change the values.                                             */
    } CG_DIVNUM3_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  CG_DIVNUM4;                      /*!< Division ration for PWM3 and PWM2 config                              */
    
    struct {
      __IO uint32_t  PWM2_DIVNUM: 12;               /*!< Division ratio of 26MHz clock to generate PWM2 clock.PWM2 clock
                                                         ON/OFF can be set on CG_CLK_CTRL2 register.This value can be
                                                          changed regardless of the clock ON/OFF.However, the output clock
                                                          may be unstable right after the change of this register.division
                                                          ratio = (this value + 1) * 2default value is 0x000 (Divided
                                                          by 2)                                                                */
      __IO uint32_t  Reserved1  :  4;               /*!< Do not change the values.                                             */
      __IO uint32_t  PWM3_DIVNUM: 12;               /*!< Division ratio of 26MHz clock to generate PWM3 clock.PWM3 clock
                                                         ON/OFF can be set on CG_CLK_CTRL2 register.This value can be
                                                          changed regardless of the clock ON/OFF.However, the output clock
                                                          may be unstable right after the change of this register.division
                                                          ratio = (this value + 1) * 2default value is 0x000 (Divided
                                                          by 2)                                                                */
      __IO uint32_t  Reserved0  :  4;               /*!< Do not change the values.                                             */
    } CG_DIVNUM4_b;                                 /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED2[2];
  
  union {
    __IO uint32_t  CG_CLK_CTRL;                     /*!< SPI Clock control                                                     */
    
    struct {
      __IO uint32_t  Reserved1  :  9;               /*!< Do not change the values.                                             */
      __IO uint32_t  SPIClkEn   :  1;               /*!< Enable SPI clock (R/W)1: Enable clock0: Disable clock (default)       */
      __IO uint32_t  Reserved0  : 22;               /*!< Do not change the values.                                             */
    } CG_CLK_CTRL_b;                                /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  CG_CLK_CTRL2;                    /*!< PWM Clock Control                                                     */
    
    struct {
      __IO uint32_t  PWM0ClkEn  :  1;               /*!< Enable PWM ch 0 fast clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM1ClkEn  :  1;               /*!< Enable PWM ch 1 fast clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM2ClkEn  :  1;               /*!< Enable PWM ch 2 fast clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM3ClkEn  :  1;               /*!< Enable PWM ch 3 fast clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM0SlpClkEn:  1;              /*!< Enable PWM ch 0 slow clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM1SlpClkEn:  1;              /*!< Enable PWM ch 1 slow clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM2SlpClkEn:  1;              /*!< Enable PWM ch 2 slow clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  PWM3SlpClkEn:  1;              /*!< Enable PWM ch 3 slow clock (R/W)1: Enable clock0: Disable clock
                                                         (default)                                                             */
      __IO uint32_t  Reserved0  : 24;               /*!< Do not change the values.                                             */
    } CG_CLK_CTRL2_b;                               /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED3[22];
  
  union {
    __IO uint32_t  CG_CG_CTRL;                      /*!< ckgn config register                                                  */
    
    struct {
      __IO uint32_t  Reserved2  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  WdCountSTOP:  1;               /*!< Start or stop WDT counter1: Stop counter0: Start counterWhen
                                                         set 1, WDT counter suspends.When set 0, WDT counter resumes.During
                                                          the system state is low power mode, WDT does not count.              */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  SoftReset  :  1;               /*!< Soft-Reset control1: Soft-Reset0: No change                           */
      __IO uint32_t  Reserved0  : 26;               /*!< Do not change the values.                                             */
    } CG_CG_CTRL_b;                                 /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED4[7];
  
  union {
    __IO uint32_t  CG_WD_INIT;                      /*!< Watchdog initial register                                             */
    
    struct {
      __IO uint32_t  WDINIT     : 21;               /*!< Set initial value of WDT counterThis value can be set from 0x1(30.5
                                                         micro seconds) to 0x1FFFFF.(64 seconds)Setting time is calculated
                                                          as below:setting time = (this value) * 30.5 micro secondsWhen
                                                          you update this value, please wait for more than 2 clocks of
                                                          SleepClk(32kHz clock) since the previous change.When the system
                                                          wakes up from low power mode, WDT counter is set this value.         */
      __IO uint32_t  Reserved0  : 11;               /*!< Do not change the values.                                             */
    } CG_WD_INIT_b;                                 /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  CG_WD_CURNT;                     /*!< Watchdog current register                                             */
    
    struct {
      __IO uint32_t  WDTCURNT   : 21;               /*!< Watchdog current valueWhen the system wakes up from low power
                                                         mode, this value becomes WDINIT value.                                */
      __IO uint32_t  Reserved0  : 11;               /*!< Do not change the values.                                             */
    } CG_WD_CURNT_b;                                /*!< BitSize                                                               */
  };
} Clock_Type;


/* ================================================================================ */
/* ================                BluetoothCounter                ================ */
/* ================================================================================ */


/**
  * @brief Bluetooth Counter (BluetoothCounter)
  */

typedef struct {                                    /*!< BluetoothCounter Structure                                            */
  __I  uint32_t  RESERVED[3];
  
  union {
    __IO uint32_t  LLC_LLCNT_HOLD_EN;               /*!< Hold Bluetooth counter                                                */
    
    struct {
      __IO uint32_t  LLCntHold  :  1;               /*!< When 0 (or arbitrary value) is set this register, the following
                                                         registers will hold the values:LLC_BC_LATCH_MA:Master Bit CounterLLC_SC_LA
                                                         TCH_MA:Master Slot CounterBefore accessing LLC_BC_LATCH_MA or
                                                          LLC_SC_LATCH_MA, please set 0 (or arbitrary value) to this register. */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } LLC_LLCNT_HOLD_EN_b;                          /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[4];
  
  union {
    __I  uint32_t  LLC_BC_LATCH_MA;                 /*!< Holding Master Bit Counter                                            */
    
    struct {
      __IO uint32_t  BCntMa_Hold: 10;               /*!< Master bit counter value."Master slot counter" counts up every
                                                         1 micro seconds.When this value is 624, this value becomes 0
                                                          and SCntMa_Hold value counts up on next count up timing.Before
                                                          reading this value, please set 0 (or arbitrary value) to LLCntHold.  */
      __I  uint32_t  Reserved0  : 22;               /*!< Do not change the values.                                             */
    } LLC_BC_LATCH_MA_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  LLC_SC_LATCH_MA;                 /*!< Holding Master Slot Counter                                           */
    
    struct {
      __IO uint32_t  SCntMa_Hold: 27;               /*!< Master slot counter value."Master slot counter" counts up every
                                                         1 slot (625 micro seconds).Before reading this value, please
                                                          set 0 (or arbitrary value) to LLCntHold.                             */
      __IO uint32_t  Reserved0  :  5;               /*!< Do not change the values.                                             */
    } LLC_SC_LATCH_MA_b;                            /*!< BitSize                                                               */
  };
} BluetoothCounter_Type;


/* ================================================================================ */
/* ================                      DMAC                      ================ */
/* ================================================================================ */


/**
  * @brief DMAC (DMAC)
  */

typedef struct {                                    /*!< DMAC Structure                                                        */
  
  union {
    __I  uint32_t  DMA_Int_Stat;                    /*!< Interrupt Status Register                                             */
    
    struct {
      __I  uint32_t  IntStatus0 :  1;               /*!< DMAC ch0 interrupt status.0: No interrupt1: Interrupt asserted.Both
                                                         DMA error and DMA done assert this bit.                               */
      __I  uint32_t  IntStatus1 :  1;               /*!< DMAC ch1 interrupt status.0: No interrupt1: Interrupt asserted.Both
                                                         DMA error and DMA done assert this bit.                               */
      __I  uint32_t  IntStatus2 :  1;               /*!< DMAC ch2 interrupt status.0: No interrupt1: Interrupt asserted.Both
                                                         DMA error and DMA done assert this bit.                               */
      __I  uint32_t  IntStatus3 :  1;               /*!< DMAC ch3 interrupt status.0: No interrupt1: Interrupt asserted.Both
                                                         DMA error and DMA done assert this bit.                               */
      __I  uint32_t  IntStatus4 :  1;               /*!< DMAC ch4 interrupt status.0: No interrupt1: Interrupt asserted.Both
                                                         DMA error and DMA done assert this bit.                               */
      __I  uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_Int_Stat_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  DMA_Int_TemCo_Stat;              /*!< Interrupt Terminal Count Status Register                              */
    
    struct {
      __I  uint32_t  IntTCStatus0:  1;              /*!< DMAC ch0 interrupt status of DMA done.0: No interrupt1: Interrupt
                                                         asserted.                                                             */
      __I  uint32_t  IntTCStatus1:  1;              /*!< DMAC ch1 interrupt status of DMA done.0: No interrupt1: Interrupt
                                                         asserted.                                                             */
      __I  uint32_t  IntTCStatus2:  1;              /*!< DMAC ch2 interrupt status of DMA done.0: No interrupt1: Interrupt
                                                         asserted.                                                             */
      __I  uint32_t  IntTCStatus3:  1;              /*!< DMAC ch3 interrupt status of DMA done.0: No interrupt1: Interrupt
                                                         asserted.                                                             */
      __I  uint32_t  IntTCStatus4:  1;              /*!< DMAC ch4 interrupt status of DMA done.0: No interrupt1: Interrupt
                                                         asserted.                                                             */
      __I  uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_Int_TemCo_Stat_b;                         /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_Int_TemCo_Clr;               /*!< Interrupt Terminal Count Clear Register                               */
    
    struct {
      __I  uint32_t  IntTCClear0:  1;               /*!< Clear DMAC ch0 DMA done interrupt.0: Invalid1: Clear                  */
      __I  uint32_t  IntTCClear1:  1;               /*!< Clear DMAC ch1 DMA done interrupt.0: Invalid1: Clear                  */
      __I  uint32_t  IntTCClear2:  1;               /*!< Clear DMAC ch2 DMA done interrupt.0: Invalid1: Clear                  */
      __I  uint32_t  IntTCClear3:  1;               /*!< Clear DMAC ch3 DMA done interrupt.0: Invalid1: Clear                  */
      __I  uint32_t  IntTCClear4:  1;               /*!< Clear DMAC ch4 DMA done interrupt.0: Invalid1: Clear                  */
      __IO uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_Int_TemCo_Clr_b;                          /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  DMA_Int_Err_Stat;                /*!< Interrupt Error Status Register                                       */
    
    struct {
      __I  uint32_t  IntErrStatus0:  1;             /*!< DMAC ch0 DMA error interrupt status0: No interrupt1: Interrupt
                                                         asserted                                                              */
      __I  uint32_t  IntErrStatus1:  1;             /*!< DMAC ch1 DMA error interrupt status0: No interrupt1: Interrupt
                                                         asserted                                                              */
      __I  uint32_t  IntErrStatus2:  1;             /*!< DMAC ch2 DMA error interrupt status0: No interrupt1: Interrupt
                                                         asserted                                                              */
      __I  uint32_t  IntErrStatus3:  1;             /*!< DMAC ch3 DMA error interrupt status0: No interrupt1: Interrupt
                                                         asserted                                                              */
      __I  uint32_t  IntErrStatus4:  1;             /*!< DMAC ch4 DMA error interrupt status0: No interrupt1: Interrupt
                                                         asserted                                                              */
      __I  uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_Int_Err_Stat_b;                           /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_Int_Err_Clr;                 /*!< Interrupt Error Clear Register                                        */
    
    struct {
      __IO uint32_t  IntErrClr0 :  1;               /*!< Clear DMAC ch0 DMA error interrupt0: Invalid1: Clear                  */
      __IO uint32_t  IntErrClr1 :  1;               /*!< Clear DMAC ch1 DMA error interrupt0: Invalid1: Clear                  */
      __IO uint32_t  IntErrClr2 :  1;               /*!< Clear DMAC ch2 DMA error interrupt0: Invalid1: Clear                  */
      __IO uint32_t  IntErrClr3 :  1;               /*!< Clear DMAC ch3 DMA error interrupt0: Invalid1: Clear                  */
      __IO uint32_t  IntErrClr4 :  1;               /*!< Clear DMAC ch4 DMA error interrupt0: Invalid1: Clear                  */
           uint32_t             :  5;
      __IO uint32_t  Reserved0  : 22;               /*!< Do not change the values.                                             */
    } DMA_Int_Err_Clr_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  DMA_RawInt_Tem_Stat;             /*!< Raw Interrupt Terminal Count Status Register                          */
    
    struct {
      __I  uint32_t  RawIntTCStatus0:  1;           /*!< Unmasked DMAC ch0 DMA done interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntTCStatus1:  1;           /*!< Unmasked DMAC ch1 DMA done interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntTCStatus2:  1;           /*!< Unmasked DMAC ch2 DMA done interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntTCStatus3:  1;           /*!< Unmasked DMAC ch3 DMA done interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntTCStatus4:  1;           /*!< Unmasked DMAC ch4 DMA done interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_RawInt_Tem_Stat_b;                        /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  DMA_RawInt_Err_Stat;             /*!< Raw Interrupt Error Status Register                                   */
    
    struct {
      __I  uint32_t  RawIntErrStatus0:  1;          /*!< Unmasked DMAC ch0 DMA error interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntErrStatus1:  1;          /*!< Unmasked DMAC ch1 DMA error interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntErrStatus2:  1;          /*!< Unmasked DMAC ch2 DMA error interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntErrStatus3:  1;          /*!< Unmasked DMAC ch3 DMA error interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  RawIntErrStatus4:  1;          /*!< Unmasked DMAC ch4 DMA error interrupt status0: No interrupt1:
                                                         Interrupt asserted                                                    */
      __I  uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_RawInt_Err_Stat_b;                        /*!< BitSize                                                               */
  };
  
  union {
    __I  uint32_t  DMA_Enable_ch;                   /*!< Enabled Channel Register                                              */
    
    struct {
      __I  uint32_t  EnabledChannel0:  1;           /*!< Enable/Disable DMAC ch00: Disable1: Enable                            */
      __I  uint32_t  EnabledChannel1:  1;           /*!< Enable/Disable DMAC ch10: Disable1: Enable                            */
      __I  uint32_t  EnabledChannel2:  1;           /*!< Enable/Disable DMAC ch20: Disable1: Enable                            */
      __I  uint32_t  EnabledChannel3:  1;           /*!< Enable/Disable DMAC ch30: Disable1: Enable                            */
      __I  uint32_t  EnabledChannel4:  1;           /*!< Enable/Disable DMAC ch40: Disable1: Enable                            */
      __I  uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_Enable_ch_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_Soft_burst_req;              /*!< Software Burtst Request Register                                      */
    
    struct {
      __IO uint32_t  SoftBReq0  :  1;               /*!< Set DMA burst request for peripheral number 00: Invalid request1:
                                                         Occur request                                                         */
      __IO uint32_t  Reserved2  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  SoftBReq2  :  1;               /*!< Set DMA burst request for peripheral number 20: Invalid request1:
                                                         Occur request                                                         */
      __IO uint32_t  Reserved1  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  SoftBReq4  :  1;               /*!< Set DMA burst request for peripheral number 40: Invalid request1:
                                                         Occur request                                                         */
      __IO uint32_t  Reserved0  : 27;               /*!< Do not change the values.                                             */
    } DMA_Soft_burst_req_b;                         /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_Soft_single_req;             /*!< Software Single Request Register                                      */
    
    struct {
      __IO uint32_t  Reserved3  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  SoftSReq1  :  1;               /*!< Set DMA single request for peripheral number 10: Invalid request1:
                                                         Occur request                                                         */
      __IO uint32_t  Reserved2  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  SoftSReq3  :  1;               /*!< Set DMA single request for peripheral number 30: Invalid request1:
                                                         Occur request                                                         */
      __IO uint32_t  Reserved1  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  SoftSReq5  :  1;               /*!< Set DMA single request for peripheral number 50: Invalid request1:
                                                         Occur request                                                         */
      __IO uint32_t  Reserved0  : 26;               /*!< Do not change the values.                                             */
    } DMA_Soft_single_req_b;                        /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED[2];
  
  union {
    __IO uint32_t  DMA_Config_req;                  /*!< Configuration Register                                                */
    
    struct {
      __IO uint32_t  E          :  1;               /*!< Control DMA circuit0: Halt1: ActiveSet 1 to read/write DMAC
                                                         registers.                                                            */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } DMA_Config_req_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[51];
  
  union {
    __IO uint32_t  DMA_ch0_Source;                  /*!< Channel0 Source Address Register                                      */
    
    struct {
      __IO uint32_t  SrcAddr    : 32;               /*!< Set DMA source addressPlease set this value when channel0 is
                                                         disabled on DMA_ch0_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch0_Source_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch0_Dest;                    /*!< Channel0 Destination Address Register                                 */
    
    struct {
      __IO uint32_t  DestAddr   : 32;               /*!< Set DMA destination addressPlease set this value when channel0
                                                         is disabled on DMA_ch0_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch0_Dest_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch0_Link;                    /*!< Channel0 Linked ListItem Register                                     */
    
    struct {
      __IO uint32_t  LLI        : 32;               /*!< Set start address of next transfer informationPlease set a value
                                                         of 0xFFFFFFF0 or less.When 0 is set, DMA channel will be disabled
                                                          after the current DMA transfer completes.Set this register to
                                                          use scatter/gather function. Scatter/gather is a function to
                                                          execute DMA repeatedly according to informations which are pre-set
                                                          on RAM.This address shall be 4-Byte aligned.                         */
    } DMA_ch0_Link_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch0_Contrl;                  /*!< Channel0 Control Register                                             */
    
    struct {
      __IO uint32_t  TransferSize: 12;              /*!< Set the number of transfersThis value is decremented on every
                                                         DMA transfer. Read this value to know the number of left transfers.When
                                                          DMA_ch_Config register [0] is enabled, this value can be read.The
                                                          number of transfers is in unit of source bit width.Source bit
                                                          width is 8bit: Set this register in unit of Byte.Source bit
                                                          width is 16bit: Set this register in unit of Half wordSource
                                                          bit width is 32bit: Set this register in unit of WordAttention:
                                                          If source bit width is smaller than destination bit width, you
                                                          s                                                                    */
      __IO uint32_t  SBSize     :  3;               /*!< Set source burst sizeSame as DBSize                                   */
      __IO uint32_t  DBSize     :  3;               /*!< Set destination burst size000: 1 beat001: 4 beat010: 8 beat011:
                                                         16 beat100: 32 beat101: 64 beat110: 128 beat111: 256 beat             */
      __IO uint32_t  SWidth     :  3;               /*!< Set source bit widthSame as DWidth                                    */
      __IO uint32_t  DWidth     :  3;               /*!< Set destination bit width000: 8bit (Byte)001: 16bit (Half word)010:
                                                         32bit (Word)Other: Reserved                                           */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  SI         :  1;               /*!< Set increment config of source address 0: Do not increment (The
                                                         address is fixed) 1: Increment Increment timming is the same
                                                          as DI.                                                               */
      __IO uint32_t  DI         :  1;               /*!< Set increment config of destination address0: Do not increment
                                                         (The address is fixed)1: IncrementIncrement timming changes
                                                          according to DWidth.Each Increment timming is as follows:Bit
                                                          width is 8bit: Increment every 1ByteBit width is 16bit: Increment
                                                          every 2ByteBit width is 32bit: Increment every 4Byte                 */
      __IO uint32_t  Reserved0  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  I          :  1;               /*!< Set interrupt enable of Terminal Count0: Disable1: Enable             */
    } DMA_ch0_Contrl_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch0_Config;                  /*!< Channel0 Configuration Register                                       */
    
    struct {
      __IO uint32_t  E          :  1;               /*!< Set channel enable0: Disable1: EnableAfter you set up the all
                                                         DMA settings, set 1 to this register.When this value set disable
                                                          during transfer, FIFO data of channel0 is erased. If you want
                                                          to restart the transfer, please initialize all config of channel0
                                                          and restart the DMA.If you want to stop the transfer temporarily,
                                                          please perform the following sequence:(1)Set 1 to register H,
                                                          then DMA requirement stop.(2)Poll FIFO data until register A
                                                          becomes 0 (FIFO if empty).(3)Set 0(disable) to this register,
                                                          and w                                                                */
      __IO uint32_t  SrcPeripheral:  4;             /*!< DMA source peripheral config registerMin: 0000Max: 1111If the
                                                         source is Memory, this value is ignored.                              */
      __IO uint32_t  Reserved2  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  DestPeripheral:  4;            /*!< DMA destination peripheral numberMin: 0000Max: 1111If the destination
                                                         is Memory, this value is ignored.                                     */
      __IO uint32_t  Reserved1  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  FlowContrl :  3;               /*!< Transfer mode config.000: Memory to Memory001: Memory to Pripheral010:
                                                         Peripheral to Memory011: Peripheral to PeripheralOther: ReservedAttention:
                                                          If Memory to Memory is chosen, the transfer can be started to
                                                          write 1 to E.                                                        */
      __IO uint32_t  IE         :  1;               /*!< DMA error interrupt enable.0: enable the interrupt1: disable
                                                         the interrupt                                                         */
      __IO uint32_t  ITC        :  1;               /*!< DMA done interrupt enable0: enable the interrupt1: disable the
                                                         interrupt                                                             */
      __IO uint32_t  L          :  1;               /*!< Set bus lock transfer config0: Forbid bus lock transfer1: Allow
                                                         bus lock transferIf bus lock transfer is allowed, specified
                                                          burst size is transferred without releassing the bus.                */
      __IO uint32_t  A          :  1;               /*!< Check FIFO data of channel00: No data in FIFO1: Data exists
                                                         in FIFO                                                               */
      __IO uint32_t  H          :  1;               /*!< Halt DMA0: No halt1: Halt(Ignore DMA request)                         */
      __IO uint32_t  Reserved0  : 13;               /*!< Alywas set 0.                                                         */
    } DMA_ch0_Config_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED2[3];
  
  union {
    __IO uint32_t  DMA_ch1_Source;                  /*!< Channel1 Source Address Register                                      */
    
    struct {
      __IO uint32_t  SrcAddr    : 32;               /*!< Set DMA source addressPlease set this value when channel1 is
                                                         disabled on DMA_ch1_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch1_Source_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch1_Dest;                    /*!< Channel1 Destination Address Register                                 */
    
    struct {
      __IO uint32_t  DestAddr   : 32;               /*!< Set DMA destination addressPlease set this value when channel1
                                                         is disabled on DMA_ch1_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch1_Dest_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch1_Link;                    /*!< Channel1 Linked ListItem Register                                     */
    
    struct {
      __IO uint32_t  LLI        : 32;               /*!< Set start address of next transfer informationPlease set a value
                                                         of 0xFFFFFFF0 or less.When 0 is set, DMA channel will be disabled
                                                          after the current DMA transfer completes.Set this register to
                                                          use scatter/gather function. Scatter/gather is a function to
                                                          execute DMA repeatedly according to informations which are pre-set
                                                          on RAM.This address shall be 4-Byte aligned.                         */
    } DMA_ch1_Link_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch1_Contrl;                  /*!< Channel1 Control Register                                             */
    
    struct {
      __IO uint32_t  TransferSize: 12;              /*!< Set the number of transfersThis value is decremented on every
                                                         DMA transfer. Read this value to know the number of left transfers.When
                                                          DMA_ch_Config register [0] is enabled, this value can be read.The
                                                          number of transfers is in unit of source bit width.Source bit
                                                          width is 8bit: Set this register in unit of Byte.Source bit
                                                          width is 16bit: Set this register in unit of Half wordSource
                                                          bit width is 32bit: Set this register in unit of WordAttention:
                                                          If source bit width is smaller than destination bit width, you
                                                          s                                                                    */
      __IO uint32_t  SBSize     :  3;               /*!< Set source burst sizeSame as DBSize                                   */
      __IO uint32_t  DBSize     :  3;               /*!< Set destination burst size000: 1 beat001: 4 beat010: 8 beat011:
                                                         16 beat100: 32 beat101: 64 beat110: 128 beat111: 256 beat             */
      __IO uint32_t  SWidth     :  3;               /*!< Set source bit widthSame as DWidth                                    */
      __IO uint32_t  DWidth     :  3;               /*!< Set destination bit width000: 8bit (Byte)001: 16bit (Half word)010:
                                                         32bit (Word)Other: Reserved                                           */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  SI         :  1;               /*!< Set increment config of source address 0: Do not increment (The
                                                         address is fixed) 1: Increment Increment timming is the same
                                                          as DI.                                                               */
      __IO uint32_t  DI         :  1;               /*!< Set increment config of destination address0: Do not increment
                                                         (The address is fixed)1: IncrementIncrement timming changes
                                                          according to DWidth.Each Increment timming is as follows:Bit
                                                          width is 8bit: Increment every 1ByteBit width is 16bit: Increment
                                                          every 2ByteBit width is 32bit: Increment every 4Byte                 */
      __IO uint32_t  Reserved0  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  I          :  1;               /*!< Set interrupt enable of Terminal Count0: Disable1: Enable             */
    } DMA_ch1_Contrl_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch1_Config;                  /*!< Channel1 Configuration Register                                       */
    
    struct {
      __IO uint32_t  E          :  1;               /*!< Set channel enable0: Disable1: EnableAfter you set up the all
                                                         DMA settings, set 1 to this register.When this value set disable
                                                          during transfer, FIFO data of channel0 is erased. If you want
                                                          to restart the transfer, please initialize all config of channel0
                                                          and restart the DMA.If you want to stop the transfer temporarily,
                                                          please perform the following sequence:(1)Set 1 to register H,
                                                          then DMA requirement stop.(2)Poll FIFO data until register A
                                                          becomes 0 (FIFO if empty).(3)Set 0(disable) to this register,
                                                          and w                                                                */
      __IO uint32_t  SrcPeripheral:  4;             /*!< DMA source peripheral config registerMin: 0000Max: 1111If the
                                                         source is Memory, this value is ignored.                              */
      __IO uint32_t  Reserved2  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  DestPeripheral:  4;            /*!< DMA destination peripheral numberMin: 0000Max: 1111If the destination
                                                         is Memory, this value is ignored.                                     */
      __IO uint32_t  Reserved1  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  FlowContrl :  3;               /*!< Transfer mode config.000: Memory to Memory001: Memory to Pripheral010:
                                                         Peripheral to Memory011: Peripheral to PeripheralOther: ReservedAttention:
                                                          If Memory to Memory is chosen, the transfer can be started to
                                                          write 1 to E.                                                        */
      __IO uint32_t  IE         :  1;               /*!< DMA error interrupt enable.0: enable the interrupt1: disable
                                                         the interrupt                                                         */
      __IO uint32_t  ITC        :  1;               /*!< DMA done interrupt enable0: enable the interrupt1: disable the
                                                         interrupt                                                             */
      __IO uint32_t  L          :  1;               /*!< Set bus lock transfer config0: Forbid bus lock transfer1: Allow
                                                         bus lock transferIf bus lock transfer is allowed, specified
                                                          burst size is transferred without releassing the bus.                */
      __IO uint32_t  A          :  1;               /*!< Check FIFO data of channel00: No data in FIFO1: Data exists
                                                         in FIFO                                                               */
      __IO uint32_t  H          :  1;               /*!< Halt DMA0: No halt1: Halt(Ignore DMA request)                         */
      __IO uint32_t  Reserved0  : 13;               /*!< Alywas set 0.                                                         */
    } DMA_ch1_Config_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED3[3];
  
  union {
    __IO uint32_t  DMA_ch2_Source;                  /*!< Channel2 Source Address Register                                      */
    
    struct {
      __IO uint32_t  SrcAddr    : 32;               /*!< Set DMA source addressPlease set this value when channel2 is
                                                         disabled on DMA_ch2_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch2_Source_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch2_Dest;                    /*!< Channel2 Destination Address Register                                 */
    
    struct {
      __IO uint32_t  DestAddr   : 32;               /*!< Set DMA destination addressPlease set this value when channel2
                                                         is disabled on DMA_ch2_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch2_Dest_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch2_Link;                    /*!< Channel2 Linked ListItem Register                                     */
    
    struct {
      __IO uint32_t  LLI        : 32;               /*!< Set start address of next transfer informationPlease set a value
                                                         of 0xFFFFFFF0 or less.When 0 is set, DMA channel will be disabled
                                                          after the current DMA transfer completes.Set this register to
                                                          use scatter/gather function. Scatter/gather is a function to
                                                          execute DMA repeatedly according to informations which are pre-set
                                                          on RAM.This address shall be 4-Byte aligned.                         */
    } DMA_ch2_Link_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch2_Contrl;                  /*!< Channel2 Control Register                                             */
    
    struct {
      __IO uint32_t  TransferSize: 12;              /*!< Set the number of transfersThis value is decremented on every
                                                         DMA transfer. Read this value to know the number of left transfers.When
                                                          DMA_ch_Config register [0] is enabled, this value can be read.The
                                                          number of transfers is in unit of source bit width.Source bit
                                                          width is 8bit: Set this register in unit of Byte.Source bit
                                                          width is 16bit: Set this register in unit of Half wordSource
                                                          bit width is 32bit: Set this register in unit of WordAttention:
                                                          If source bit width is smaller than destination bit width, you
                                                          s                                                                    */
      __IO uint32_t  SBSize     :  3;               /*!< Set source burst sizeSame as DBSize                                   */
      __IO uint32_t  DBSize     :  3;               /*!< Set destination burst size000: 1 beat001: 4 beat010: 8 beat011:
                                                         16 beat100: 32 beat101: 64 beat110: 128 beat111: 256 beat             */
      __IO uint32_t  SWidth     :  3;               /*!< Set source bit widthSame as DWidth                                    */
      __IO uint32_t  DWidth     :  3;               /*!< Set destination bit width000: 8bit (Byte)001: 16bit (Half word)010:
                                                         32bit (Word)Other: Reserved                                           */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  SI         :  1;               /*!< Set increment config of source address 0: Do not increment (The
                                                         address is fixed) 1: Increment Increment timming is the same
                                                          as DI.                                                               */
      __IO uint32_t  DI         :  1;               /*!< Set increment config of destination address0: Do not increment
                                                         (The address is fixed)1: IncrementIncrement timming changes
                                                          according to DWidth.Each Increment timming is as follows:Bit
                                                          width is 8bit: Increment every 1ByteBit width is 16bit: Increment
                                                          every 2ByteBit width is 32bit: Increment every 4Byte                 */
      __IO uint32_t  Reserved0  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  I          :  1;               /*!< Set interrupt enable of Terminal Count0: Disable1: Enable             */
    } DMA_ch2_Contrl_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch2_Config;                  /*!< Channel2 Configuration Register                                       */
    
    struct {
      __IO uint32_t  E          :  1;               /*!< Set channel enable0: Disable1: EnableAfter you set up the all
                                                         DMA settings, set 1 to this register.When this value set disable
                                                          during transfer, FIFO data of channel0 is erased. If you want
                                                          to restart the transfer, please initialize all config of channel0
                                                          and restart the DMA.If you want to stop the transfer temporarily,
                                                          please perform the following sequence:(1)Set 1 to register H,
                                                          then DMA requirement stop.(2)Poll FIFO data until register A
                                                          becomes 0 (FIFO if empty).(3)Set 0(disable) to this register,
                                                          and w                                                                */
      __IO uint32_t  SrcPeripheral:  4;             /*!< DMA source peripheral config registerMin: 0000Max: 1111If the
                                                         source is Memory, this value is ignored.                              */
      __IO uint32_t  Reserved2  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  DestPeripheral:  4;            /*!< DMA destination peripheral numberMin: 0000Max: 1111If the destination
                                                         is Memory, this value is ignored.                                     */
      __IO uint32_t  Reserved1  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  FlowContrl :  3;               /*!< Transfer mode config.000: Memory to Memory001: Memory to Pripheral010:
                                                         Peripheral to Memory011: Peripheral to PeripheralOther: ReservedAttention:
                                                          If Memory to Memory is chosen, the transfer can be started to
                                                          write 1 to E.                                                        */
      __IO uint32_t  IE         :  1;               /*!< DMA error interrupt enable.0: enable the interrupt1: disable
                                                         the interrupt                                                         */
      __IO uint32_t  ITC        :  1;               /*!< DMA done interrupt enable0: enable the interrupt1: disable the
                                                         interrupt                                                             */
      __IO uint32_t  L          :  1;               /*!< Set bus lock transfer config0: Forbid bus lock transfer1: Allow
                                                         bus lock transferIf bus lock transfer is allowed, specified
                                                          burst size is transferred without releassing the bus.                */
      __IO uint32_t  A          :  1;               /*!< Check FIFO data of channel00: No data in FIFO1: Data exists
                                                         in FIFO                                                               */
      __IO uint32_t  H          :  1;               /*!< Halt DMA0: No halt1: Halt(Ignore DMA request)                         */
      __IO uint32_t  Reserved0  : 13;               /*!< Alywas set 0.                                                         */
    } DMA_ch2_Config_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED4[3];
  
  union {
    __IO uint32_t  DMA_ch3_Source;                  /*!< Channel3 Source Address Register                                      */
    
    struct {
      __IO uint32_t  SrcAddr    : 32;               /*!< Set DMA source addressPlease set this value when channel3 is
                                                         disabled on DMA_ch3_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch3_Source_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch3_Dest;                    /*!< Channel3 Destination Address Register                                 */
    
    struct {
      __IO uint32_t  DestAddr   : 32;               /*!< Set DMA destination addressPlease set this value when channel3
                                                         is disabled on DMA_ch3_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch3_Dest_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch3_Link;                    /*!< Channel3 Linked ListItem Register                                     */
    
    struct {
      __IO uint32_t  LLI        : 32;               /*!< Set start address of next transfer informationPlease set a value
                                                         of 0xFFFFFFF0 or less.When 0 is set, DMA channel will be disabled
                                                          after the current DMA transfer completes.Set this register to
                                                          use scatter/gather function. Scatter/gather is a function to
                                                          execute DMA repeatedly according to informations which are pre-set
                                                          on RAM.This address shall be 4-Byte aligned.                         */
    } DMA_ch3_Link_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch3_Contrl;                  /*!< Channel3 Control Register                                             */
    
    struct {
      __IO uint32_t  TransferSize: 12;              /*!< Set the number of transfersThis value is decremented on every
                                                         DMA transfer. Read this value to know the number of left transfers.When
                                                          DMA_ch_Config register [0] is enabled, this value can be read.The
                                                          number of transfers is in unit of source bit width.Source bit
                                                          width is 8bit: Set this register in unit of Byte.Source bit
                                                          width is 16bit: Set this register in unit of Half wordSource
                                                          bit width is 32bit: Set this register in unit of WordAttention:
                                                          If source bit width is smaller than destination bit width, you
                                                          s                                                                    */
      __IO uint32_t  SBSize     :  3;               /*!< Set source burst sizeSame as DBSize                                   */
      __IO uint32_t  DBSize     :  3;               /*!< Set destination burst size000: 1 beat001: 4 beat010: 8 beat011:
                                                         16 beat100: 32 beat101: 64 beat110: 128 beat111: 256 beat             */
      __IO uint32_t  SWidth     :  3;               /*!< Set source bit widthSame as DWidth                                    */
      __IO uint32_t  DWidth     :  3;               /*!< Set destination bit width000: 8bit (Byte)001: 16bit (Half word)010:
                                                         32bit (Word)Other: Reserved                                           */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  SI         :  1;               /*!< Set increment config of source address 0: Do not increment (The
                                                         address is fixed) 1: Increment Increment timming is the same
                                                          as DI.                                                               */
      __IO uint32_t  DI         :  1;               /*!< Set increment config of destination address0: Do not increment
                                                         (The address is fixed)1: IncrementIncrement timming changes
                                                          according to DWidth.Each Increment timming is as follows:Bit
                                                          width is 8bit: Increment every 1ByteBit width is 16bit: Increment
                                                          every 2ByteBit width is 32bit: Increment every 4Byte                 */
      __IO uint32_t  Reserved0  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  I          :  1;               /*!< Set interrupt enable of Terminal Count0: Disable1: Enable             */
    } DMA_ch3_Contrl_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch3_Config;                  /*!< Channel3 Configuration Register                                       */
    
    struct {
      __IO uint32_t  E          :  1;               /*!< Set channel enable0: Disable1: EnableAfter you set up the all
                                                         DMA settings, set 1 to this register.When this value set disable
                                                          during transfer, FIFO data of channel0 is erased. If you want
                                                          to restart the transfer, please initialize all config of channel0
                                                          and restart the DMA.If you want to stop the transfer temporarily,
                                                          please perform the following sequence:(1)Set 1 to register H,
                                                          then DMA requirement stop.(2)Poll FIFO data until register A
                                                          becomes 0 (FIFO if empty).(3)Set 0(disable) to this register,
                                                          and w                                                                */
      __IO uint32_t  SrcPeripheral:  4;             /*!< DMA source peripheral config registerMin: 0000Max: 1111If the
                                                         source is Memory, this value is ignored.                              */
      __IO uint32_t  Reserved2  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  DestPeripheral:  4;            /*!< DMA destination peripheral numberMin: 0000Max: 1111If the destination
                                                         is Memory, this value is ignored.                                     */
      __IO uint32_t  Reserved1  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  FlowContrl :  3;               /*!< Transfer mode config.000: Memory to Memory001: Memory to Pripheral010:
                                                         Peripheral to Memory011: Peripheral to PeripheralOther: ReservedAttention:
                                                          If Memory to Memory is chosen, the transfer can be started to
                                                          write 1 to E.                                                        */
      __IO uint32_t  IE         :  1;               /*!< DMA error interrupt enable.0: enable the interrupt1: disable
                                                         the interrupt                                                         */
      __IO uint32_t  ITC        :  1;               /*!< DMA done interrupt enable0: enable the interrupt1: disable the
                                                         interrupt                                                             */
      __IO uint32_t  L          :  1;               /*!< Set bus lock transfer config0: Forbid bus lock transfer1: Allow
                                                         bus lock transferIf bus lock transfer is allowed, specified
                                                          burst size is transferred without releassing the bus.                */
      __IO uint32_t  A          :  1;               /*!< Check FIFO data of channel00: No data in FIFO1: Data exists
                                                         in FIFO                                                               */
      __IO uint32_t  H          :  1;               /*!< Halt DMA0: No halt1: Halt(Ignore DMA request)                         */
      __IO uint32_t  Reserved0  : 13;               /*!< Alywas set 0.                                                         */
    } DMA_ch3_Config_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED5[3];
  
  union {
    __IO uint32_t  DMA_ch4_Source;                  /*!< Channel4 Source Address Register                                      */
    
    struct {
      __IO uint32_t  SrcAddr    : 32;               /*!< Set DMA source addressPlease set this value when channel4 is
                                                         disabled on DMA_ch4_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch4_Source_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch4_Dest;                    /*!< Channel4 Destination Address Register                                 */
    
    struct {
      __IO uint32_t  DestAddr   : 32;               /*!< Set DMA destination addressPlease set this value when channel4
                                                         is disabled on DMA_ch4_Config register.Do not update this value
                                                          while data are transferred by DMA.This address shall be 4-Byte
                                                          aligned.                                                             */
    } DMA_ch4_Dest_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch4_Link;                    /*!< Channel4 Linked ListItem Register                                     */
    
    struct {
      __IO uint32_t  LLI        : 32;               /*!< Set start address of next transfer informationPlease set a value
                                                         of 0xFFFFFFF0 or less.When 0 is set, DMA channel will be disabled
                                                          after the current DMA transfer completes.Set this register to
                                                          use scatter/gather function. Scatter/gather is a function to
                                                          execute DMA repeatedly according to informations which are pre-set
                                                          on RAM.This address shall be 4-Byte aligned.                         */
    } DMA_ch4_Link_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch4_Contrl;                  /*!< Channel4 Control Register                                             */
    
    struct {
      __IO uint32_t  TransferSize: 12;              /*!< Set the number of transfersThis value is decremented on every
                                                         DMA transfer. Read this value to know the number of left transfers.When
                                                          DMA_ch_Config register [0] is enabled, this value can be read.The
                                                          number of transfers is in unit of source bit width.Source bit
                                                          width is 8bit: Set this register in unit of Byte.Source bit
                                                          width is 16bit: Set this register in unit of Half wordSource
                                                          bit width is 32bit: Set this register in unit of WordAttention:
                                                          If source bit width is smaller than destination bit width, you
                                                          s                                                                    */
      __IO uint32_t  SBSize     :  3;               /*!< Set source burst sizeSame as DBSize                                   */
      __IO uint32_t  DBSize     :  3;               /*!< Set destination burst size000: 1 beat001: 4 beat010: 8 beat011:
                                                         16 beat100: 32 beat101: 64 beat110: 128 beat111: 256 beat             */
      __IO uint32_t  SWidth     :  3;               /*!< Set source bit widthSame as DWidth                                    */
      __IO uint32_t  DWidth     :  3;               /*!< Set destination bit width000: 8bit (Byte)001: 16bit (Half word)010:
                                                         32bit (Word)Other: Reserved                                           */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  SI         :  1;               /*!< Set increment config of source address 0: Do not increment (The
                                                         address is fixed) 1: Increment Increment timming is the same
                                                          as DI.                                                               */
      __IO uint32_t  DI         :  1;               /*!< Set increment config of destination address0: Do not increment
                                                         (The address is fixed)1: IncrementIncrement timming changes
                                                          according to DWidth.Each Increment timming is as follows:Bit
                                                          width is 8bit: Increment every 1ByteBit width is 16bit: Increment
                                                          every 2ByteBit width is 32bit: Increment every 4Byte                 */
      __IO uint32_t  Reserved0  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  I          :  1;               /*!< Set interrupt enable of Terminal Count0: Disable1: Enable             */
    } DMA_ch4_Contrl_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  DMA_ch4_Config;                  /*!< Channel4 Configuration Register                                       */
    
    struct {
      __IO uint32_t  E          :  1;               /*!< Set channel enable0: Disable1: EnableAfter you set up the all
                                                         DMA settings, set 1 to this register.When this value set disable
                                                          during transfer, FIFO data of channel0 is erased. If you want
                                                          to restart the transfer, please initialize all config of channel0
                                                          and restart the DMA.If you want to stop the transfer temporarily,
                                                          please perform the following sequence:(1)Set 1 to register H,
                                                          then DMA requirement stop.(2)Poll FIFO data until register A
                                                          becomes 0 (FIFO if empty).(3)Set 0(disable) to this register,
                                                          and w                                                                */
      __IO uint32_t  SrcPeripheral:  4;             /*!< DMA source peripheral config registerMin: 0000Max: 1111If the
                                                         source is Memory, this value is ignored.                              */
      __IO uint32_t  Reserved2  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  DestPeripheral:  4;            /*!< DMA destination peripheral numberMin: 0000Max: 1111If the destination
                                                         is Memory, this value is ignored.                                     */
      __IO uint32_t  Reserved1  :  1;               /*!< Always set 0.                                                         */
      __IO uint32_t  FlowContrl :  3;               /*!< Transfer mode config.000: Memory to Memory001: Memory to Pripheral010:
                                                         Peripheral to Memory011: Peripheral to PeripheralOther: ReservedAttention:
                                                          If Memory to Memory is chosen, the transfer can be started to
                                                          write 1 to E.                                                        */
      __IO uint32_t  IE         :  1;               /*!< DMA error interrupt enable.0: enable the interrupt1: disable
                                                         the interrupt                                                         */
      __IO uint32_t  ITC        :  1;               /*!< DMA done interrupt enable0: enable the interrupt1: disable the
                                                         interrupt                                                             */
      __IO uint32_t  L          :  1;               /*!< Set bus lock transfer config0: Forbid bus lock transfer1: Allow
                                                         bus lock transferIf bus lock transfer is allowed, specified
                                                          burst size is transferred without releassing the bus.                */
      __IO uint32_t  A          :  1;               /*!< Check FIFO data of channel00: No data in FIFO1: Data exists
                                                         in FIFO                                                               */
      __IO uint32_t  H          :  1;               /*!< Halt DMA0: No halt1: Halt(Ignore DMA request)                         */
      __IO uint32_t  Reserved0  : 13;               /*!< Alywas set 0.                                                         */
    } DMA_ch4_Config_b;                             /*!< BitSize                                                               */
  };
} DMAC_Type;


/* ================================================================================ */
/* ================                 PowerManagement                ================ */
/* ================================================================================ */


/**
  * @brief Power Management (GPIO, RTC) (PowerManagement)
  */

typedef struct {                                    /*!< PowerManagement Structure                                             */
  __I  uint32_t  RESERVED[23];
  
  union {
    __IO uint32_t  PMU_RTCWAKEUPCFG;                /*!< RTC wakeup config register                                            */
    
    struct {
      __IO uint32_t  RTCWAKEUPEN:  1;               /*!< RTC wakeup config1: Enable wakeup by RTC0: Disable wakeup by
                                                         RTC                                                                   */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } PMU_RTCWAKEUPCFG_b;                           /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[6];
  
  union {
    __IO uint32_t  PMU_IOSTANDBYX;                  /*!< GPIO input standby                                                    */
    
    struct {
      __IO uint32_t  GPIO0nputStandbyRelease:  1;   /*!< Input standby release on GPIO01: Release standby0: Standby            */
      __IO uint32_t  GPIO1nputStandbyRelease:  1;   /*!< Input standby release on GPIO11: Release standby0: Standby            */
      __IO uint32_t  GPIO2nputStandbyRelease:  1;   /*!< Input standby release on GPIO21: Release standby0: Standby            */
      __IO uint32_t  GPIO3nputStandbyRelease:  1;   /*!< Input standby release on GPIO31: Release standby0: Standby            */
      __IO uint32_t  GPIO4nputStandbyRelease:  1;   /*!< Input standby release on GPIO41: Release standby0: Standby            */
      __IO uint32_t  GPIO5nputStandbyRelease:  1;   /*!< Input standby release on GPIO51: Release standby0: Standby            */
      __IO uint32_t  GPIO6nputStandbyRelease:  1;   /*!< Input standby release on GPIO61: Release standby0: Standby            */
      __IO uint32_t  GPIO7nputStandbyRelease:  1;   /*!< Input standby release on GPIO71: Release standby0: Standby            */
      __IO uint32_t  GPIO8nputStandbyRelease:  1;   /*!< Input standby release on GPIO81: Release standby0: Standby            */
      __IO uint32_t  GPIO9nputStandbyRelease:  1;   /*!< Input standby release on GPIO91: Release standby0: Standby            */
      __IO uint32_t  GPIO10nputStandbyRelease:  1;  /*!< Input standby release on GPIO101: Release standby0: Standby           */
      __IO uint32_t  GPIO11nputStandbyRelease:  1;  /*!< Input standby release on GPIO111: Release standby0: Standby           */
      __IO uint32_t  GPIO12nputStandbyRelease:  1;  /*!< Input standby release on GPIO121: Release standby0: Standby           */
      __IO uint32_t  GPIO13nputStandbyRelease:  1;  /*!< Input standby release on GPIO131: Release standby0: Standby           */
      __IO uint32_t  GPIO14nputStandbyRelease:  1;  /*!< Input standby release on GPIO141: Release standby0: Standby           */
      __IO uint32_t  GPIO15nputStandbyRelease:  1;  /*!< Input standby release on GPIO151: Release standby0: Standby           */
      __IO uint32_t  GPIO16nputStandbyRelease:  1;  /*!< Input standby release on GPIO161: Release standby0: Standby           */
      __IO uint32_t  GPIO17nputStandbyRelease:  1;  /*!< Input standby release on GPIO171: Release standby0: Standby           */
      __IO uint32_t  GPIO18nputStandbyRelease:  1;  /*!< Input standby release on GPIO181: Release standby0: Standby           */
      __IO uint32_t  GPIO19nputStandbyRelease:  1;  /*!< Input standby release on GPIO191: Release standby0: Standby           */
      __IO uint32_t  GPIO20nputStandbyRelease:  1;  /*!< Input standby release on GPIO201: Release standby0: Standby           */
      __IO uint32_t  GPIO21nputStandbyRelease:  1;  /*!< Input standby release on GPIO211: Release standby0: Standby           */
      __IO uint32_t  GPIO22nputStandbyRelease:  1;  /*!< Input standby release on GPIO221: Release standby0: Standby           */
      __IO uint32_t  GPIO23nputStandbyRelease:  1;  /*!< Input standby release on GPIO231: Release standby0: Standby           */
      __IO uint32_t  GPIO24nputStandbyRelease:  1;  /*!< Input standby release on GPIO241: Release standby0: Standby           */
      __IO uint32_t  GPIO25nputStandbyRelease:  1;  /*!< Input standby release on GPIO251: Release standby0: Standby           */
      __IO uint32_t  GPIO26nputStandbyRelease:  1;  /*!< Input standby release on GPIO261: Release standby0: Standby           */
      __IO uint32_t  GPIO27nputStandbyRelease:  1;  /*!< Input standby release on GPIO271: Release standby0: Standby           */
      __IO uint32_t  GPIO28nputStandbyRelease:  1;  /*!< Input standby release on GPIO281: Release standby0: Standby           */
      __IO uint32_t  GPIO29nputStandbyRelease:  1;  /*!< Input standby release on GPIO291: Release standby0: Standby           */
      __IO uint32_t  GPIO30nputStandbyRelease:  1;  /*!< Input standby release on GPIO301: Release standby0: Standby           */
      __IO uint32_t  GPIO31nputStandbyRelease:  1;  /*!< Input standby release on GPIO311: Release standby0: Standby           */
    } PMU_IOSTANDBYX_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED2[13];
  
  union {
    __IO uint32_t  PMU_RTC_TIME;                    /*!< RTC time register                                                     */
    
    struct {
      __IO uint32_t  RTCSECONDSET:  7;              /*!< RTC time config of "second"(Binary Coded Decimal)Min: 0Max:
                                                         59                                                                    */
      __IO uint32_t  Reserved3  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCMINUTESET:  7;              /*!< RTC time config of "minute"(Binary Coded Decimal)Min: 0Max:
                                                         59                                                                    */
      __IO uint32_t  Reserved2  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCHOURSET :  6;               /*!< RTC time config of "hour"(Binary Coded Decimal)Min: 0Max: 23          */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCDAYSET  :  6;               /*!< RTC time config of "day"(Binary Coded Decimal)Min: 1Max: 31           */
      __IO uint32_t  Reserved0  :  2;               /*!< Do not change the values.                                             */
    } PMU_RTC_TIME_b;                               /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PMU_RTC_DAY;                     /*!< RTC date register                                                     */
    
    struct {
      __IO uint32_t  RTCWEEK    :  3;               /*!< RTC date config of "week"(Binary Coded Decimal)                       */
      __IO uint32_t  Reserved1  : 13;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCMONTH   :  5;               /*!< RTC date config of "month"(Binary Coded Decimal)                      */
      __IO uint32_t  Reserved0  :  3;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCYEAR    :  8;               /*!< RTC date config of "year"(Binary Coded Decimal)                       */
    } PMU_RTC_DAY_b;                                /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PMU_RTC_PAGER;                   /*!< RTC control config register                                           */
    
    struct {
      __IO uint32_t  PAGE       :  1;               /*!< Set Page config0: Choose Page01: Choose Page1                         */
      __IO uint32_t  Reserved2  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  ENAALM     :  1;               /*!< Set alarm config0: Disable1: Enable                                   */
      __IO uint32_t  ENATMR     :  1;               /*!< Set clock config0: Disable1: Enable                                   */
      __IO uint32_t  Reserved1  :  3;               /*!< Always set 0.                                                         */
      __IO uint32_t  INTENA     :  1;               /*!< Set interrupt config0: Disabel1: Enable                               */
      __IO uint32_t  Reserved0  : 24;               /*!< Do not change the values.                                             */
    } PMU_RTC_PAGER_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PMU_RTC_RESTR;                   /*!< RTC reset register                                                    */
    
    struct {
      __IO uint32_t  Reserved1  :  4;               /*!< Do not change the values.                                             */
      __IO uint32_t  RSTALM     :  1;               /*!< Reset alarm0: Not reset1: ResetIf you wan to reset an alarm,
                                                         please set 1 to this value and wait to become 0.                      */
      __IO uint32_t  RSTTMR     :  1;               /*!< Reset clock0: Not reset1: ResetIf you wan to reset a clock,
                                                         please set 1 to this value and wait to become 0.                      */
      __IO uint32_t  Reserved0  : 26;               /*!< Always set 0b0000_0000_1100_0001_0000_0000_11                         */
    } PMU_RTC_RESTR_b;                              /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED3;
  
  union {
    __IO uint32_t  PMU_RTC_TIME2;                   /*!< RTC time register2                                                    */
    
    struct {
      __IO uint32_t  Reserved3  :  8;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCMINUTESET:  7;              /*!< RTC time config of "minute"(Binary Coded Decimal)Min: 0Max:
                                                         59                                                                    */
      __IO uint32_t  Reserved2  :  1;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCHOURSET :  6;               /*!< RTC time config of "hour" (Binary Coded Decimal)Min: 0Max: 23         */
      __IO uint32_t  Reserved1  :  2;               /*!< Do not change the values.                                             */
      __IO uint32_t  RTCDAYSET  :  6;               /*!< RTC time config of "day" (Binary Coded Decimal)Min: 1Max: 31          */
      __IO uint32_t  Reserved0  :  2;               /*!< Do not change the values.                                             */
    } PMU_RTC_TIME2_b;                              /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED4[2];
  
  union {
    __IO uint32_t  PMU_RTC_INTCLR;                  /*!< RTC interrupt clear register                                          */
    
    struct {
      __IO uint32_t  RTCINTclr  :  1;               /*!< Clear RTC interrupt1: Clear0: Don't care                              */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } PMU_RTC_INTCLR_b;                             /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PMU_RTC_INTEN;                   /*!< RTC interrupt enable register                                         */
    
    struct {
      __IO uint32_t  RTCINTEN   :  1;               /*!< Enable RTC interrupt1: Enable interrupt request0: Disable interrupt
                                                         request                                                               */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } PMU_RTC_INTEN_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PMU_RTC_CNTCFG;                  /*!< RTC count cnofig register                                             */
    
    struct {
      __IO uint32_t  RTCNTCFG   :  1;               /*!< Set RTC config1: Enable RTC config0: Disable RTC config               */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } PMU_RTC_CNTCFG_b;                             /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED5[3];
  
  union {
    __I  uint32_t  PMU_DD_DVSSEL;                   /*!< DCDC DVS control register                                             */
    
    struct {
      __I  uint32_t  val        : 32;               /*!< Do not change this value.                                             */
    } PMU_DD_DVSSEL_b;                              /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED6[11];
  
  union {
    __IO uint32_t  PMU_XOSC_TRIMIN;                 /*!< XOSC trimming register                                                */
    
    struct {
      __IO uint32_t  Reserved1  :  4;               /*!< Reserved.Since this bits are regulated during the chip manufacturing,do
                                                         not change value. (Use read-modify-write).                            */
      __IO uint32_t  XO_FREQ_TUNE:  7;              /*!< Frequency tune value.                                                 */
      __IO uint32_t  Reserved0  : 21;               /*!< Reserved.Since this bits are regulated during the chip manufacturing,do
                                                         not change value. (Use read-modify-write).                            */
    } PMU_XOSC_TRIMIN_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  PMU_OSC32K_TRIMIN;               /*!< OSC32K trimming register                                              */
    
    struct {
      __IO uint32_t  Reserved1  : 16;               /*!< Reserved.Since this bits are regulated during the chip manufacturing,do
                                                         not change value. (Use read-modify-write).                            */
      __IO uint32_t  FREQTUNE_OSC32K:  5;           /*!< Freqency tune value.                                                  */
      __IO uint32_t  Reserved0  : 11;               /*!< Do not change the values.                                             */
    } PMU_OSC32K_TRIMIN_b;                          /*!< BitSize                                                               */
  };
} PowerManagement_Type;


/* ================================================================================ */
/* ================                    TimerBCG                    ================ */
/* ================================================================================ */


/**
  * @brief Timer (BCTimer, GTimer) (TimerBCG)
  */

typedef struct {                                    /*!< TimerBCG Structure                                                    */
  
  union {
    __IO uint32_t  TIM_BCTIMER_CTRL;                /*!< Bit Clock Timer Control                                               */
    
    struct {
      __IO uint32_t  AEn        :  1;               /*!< Enable autoreload feature for timer A0: Stop when Timer A gets
                                                         0.1: Reload the initial value when Timer A gets 0.                    */
      __IO uint32_t  BEn        :  1;               /*!< Enable autoreload feature for timer B0: Stop when Timer B gets
                                                         0.1: Reload the initial value when Timer B gets 0.                    */
      __IO uint32_t  CEn        :  1;               /*!< Enable autoreload feature for timer C0: Stop when Timer C gets
                                                         0.1: Reload the initial value when Timer C gets 0.                    */
      __I  uint32_t  Reserved1  :  5;               /*!< Reserved.                                                             */
      __IO uint32_t  INTM1      :  1;               /*!< Timer A Interrupt mask0: the interrupt is not masked1: the interutpt
                                                         is masked                                                             */
      __IO uint32_t  INTMB      :  1;               /*!< Timer B Interrupt mask0: the interrupt is not masked1: the interutpt
                                                         is masked                                                             */
      __IO uint32_t  INTMC      :  1;               /*!< Timer C Interrupt mask0: the interrupt is not masked1: the interutpt
                                                         is masked                                                             */
      __I  uint32_t  Reserved0  : 21;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_CTRL_b;                           /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_STAT;                /*!< Bit Clock Timer Status                                                */
    
    struct {
      __IO uint32_t  TimerAInt  :  1;               /*!< Interrupt from Timer A0: No interrupt from Timer A.1: Interrupt
                                                         from Timer A exist.                                                   */
      __IO uint32_t  TimerBInt  :  1;               /*!< Interrupt from Timer B0: No interrupt from Timer B.1: Interrupt
                                                         from Timer B exist.                                                   */
      __IO uint32_t  TimerCInt  :  1;               /*!< Interrupt from Timer C0: No interrupt from Timer C.1: Interrupt
                                                         from Timer C exist.                                                   */
      __I  uint32_t  Reserved0  : 29;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_STAT_b;                           /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_A;                   /*!< Bit Clock Timer A control                                             */
    
    struct {
      __IO uint32_t  TimA       : 16;               /*!< Start Value Timer A Set the initial value of Timer A.                 */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_A_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_B;                   /*!< Bit Clock Timer B control                                             */
    
    struct {
      __IO uint32_t  TimB       : 16;               /*!< Start Value Timer B Set the initial value of Timer B.                 */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_B_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_C;                   /*!< Bit Clock Timer C control                                             */
    
    struct {
      __IO uint32_t  TimC       : 16;               /*!< Start Value Timer C Set the initial value of Timer C.                 */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_C_b;                              /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_A_RD;                /*!< Bit Clock Timer A read                                                */
    
    struct {
      __IO uint32_t  TimARd     : 16;               /*!< Current Value of Timer A                                              */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_A_RD_b;                           /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_B_RD;                /*!< Bit Clock Timer B read                                                */
    
    struct {
      __IO uint32_t  TimBRd     : 16;               /*!< Current Value of Timer B                                              */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_B_RD_b;                           /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_BCTIMER_C_RD;                /*!< Bit Clock Timer C read                                                */
    
    struct {
      __IO uint32_t  TimCRd     : 16;               /*!< Current Value of Timer C                                              */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_BCTIMER_C_RD_b;                           /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED[56];
  
  union {
    __IO uint32_t  TIM_GTIMER_CTRL;                 /*!< Timer Control                                                         */
    
    struct {
      __IO uint32_t  AEn        :  1;               /*!< Enable auto reload feature for Timer A                                */
      __I  uint32_t  Reserved2  :  7;               /*!< Do not change the values.                                             */
      __IO uint32_t  INTMA      :  1;               /*!< Timer A Interrupt mask0: the interrupt is not masked1: the interutpt
                                                         is masked                                                             */
      __I  uint32_t  Reserved1  :  7;               /*!< Do not change the values.                                             */
      __IO uint32_t  PRESCALERVAL: 10;              /*!< Settings for frequency divider of TimerSCLK to generate timer
                                                         clock.0x000 : No divide0x001 : 1/20x002 : 1/3........0x3ff :
                                                          1/1024                                                               */
      __I  uint32_t  Reserved0  :  6;               /*!< Do not change the values.                                             */
    } TIM_GTIMER_CTRL_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_GTIMER_STAT;                 /*!< Timer Status                                                          */
    
    struct {
      __IO uint32_t  TimerAInt  :  1;               /*!< Interrutp bit from Timer A0: No interrupt from Timer A.1: Interrupt
                                                         from Timer A exist.                                                   */
      __IO uint32_t  Reserved0  : 31;               /*!< Do not change the values.                                             */
    } TIM_GTIMER_STAT_b;                            /*!< BitSize                                                               */
  };
  
  union {
    __IO uint32_t  TIM_GTIMER_A;                    /*!< Timer Initial Value                                                   */
    
    struct {
      __IO uint32_t  TimARd     : 16;               /*!< Start Value of TimerA.                                                */
      __I  uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_GTIMER_A_b;                               /*!< BitSize                                                               */
  };
  __I  uint32_t  RESERVED1[2];
  
  union {
    __IO uint32_t  TIM_GTIMER_A_RD;                 /*!< Timer Value read                                                      */
    
    struct {
      __IO uint32_t  TimerARd   : 16;               /*!< Current Value of Timer A.                                             */
      __IO uint32_t  Reserved0  : 16;               /*!< Do not change the values.                                             */
    } TIM_GTIMER_A_RD_b;                            /*!< BitSize                                                               */
  };
} TimerBCG_Type;


/* --------------------  End of section using anonymous unions  ------------------- */
#if defined(__CC_ARM)
  #pragma pop
#elif defined(__ICCARM__)
  /* leave anonymous unions enabled */
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined(__TASKING__)
  #pragma warning restore
#else
  #warning Not supported compiler type
#endif




/* ================================================================================ */
/* ================              Peripheral memory map             ================ */
/* ================================================================================ */

#define PWM_BASE                        0x4004A100UL
#define GPIO_BASE                       0x4004E000UL
#define SPI_BASE                        0x40046000UL
#define Clock_BASE                      0x4004C000UL
#define BluetoothCounter_BASE           0x40040240UL
#define DMAC_BASE                       0x40001000UL
#define PowerManagement_BASE            0x40055000UL
#define TimerBCG_BASE                   0x4004D000UL


/* ================================================================================ */
/* ================             Peripheral declaration             ================ */
/* ================================================================================ */

#define PWM                             ((PWM_Type                *) PWM_BASE)
#define GPIO                            ((GPIO_Type               *) GPIO_BASE)
#define SPI                             ((SPI_Type                *) SPI_BASE)
#define Clock                           ((Clock_Type              *) Clock_BASE)
#define BluetoothCounter                ((BluetoothCounter_Type   *) BluetoothCounter_BASE)
#define DMAC                            ((DMAC_Type               *) DMAC_BASE)
#define PowerManagement                 ((PowerManagement_Type    *) PowerManagement_BASE)
#define TimerBCG                        ((TimerBCG_Type           *) TimerBCG_BASE)


/** @} */ /* End of group Device_Peripheral_Registers */
/** @} */ /* End of group TC3567C */
/** @} */ /* End of group (null) */

#ifdef __cplusplus
}
#endif


#endif  /* TC3567C_H */

